"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 6afa296e99ce

from .clienterror import ClientError
from typing import Any, TYPE_CHECKING

from mollie.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .address import Address, AddressTypedDict
    from .amount import Amount, AmountTypedDict
    from .amount_nullable import AmountNullable, AmountNullableTypedDict
    from .apierror import APIError
    from .balance_card_audience import BalanceCardAudience
    from .balance_card_issuer import BalanceCardIssuer
    from .balance_card_region import BalanceCardRegion
    from .balance_fee_type import BalanceFeeType
    from .balance_prepayment_part_type import BalancePrepaymentPartType
    from .balance_report_grouping import BalanceReportGrouping
    from .balance_transaction_type import BalanceTransactionType
    from .balance_transfer_category import BalanceTransferCategory
    from .balance_transfer_category_response import BalanceTransferCategoryResponse
    from .balance_transfer_destination_type import BalanceTransferDestinationType
    from .balance_transfer_party_type import BalanceTransferPartyType
    from .balance_transfer_party_type_response import BalanceTransferPartyTypeResponse
    from .balance_transfer_status import BalanceTransferStatus
    from .balance_transfer_status_reason_response import (
        BalanceTransferStatusReasonResponse,
    )
    from .billingaddress import BillingAddress, BillingAddressTypedDict
    from .cancel_paymentop import (
        CancelPaymentRequest,
        CancelPaymentRequestBody,
        CancelPaymentRequestBodyTypedDict,
        CancelPaymentRequestTypedDict,
    )
    from .cancel_refundop import (
        CancelRefundGlobals,
        CancelRefundGlobalsTypedDict,
        CancelRefundRequest,
        CancelRefundRequestTypedDict,
    )
    from .cancel_subscriptionop import (
        CancelSubscriptionRequest,
        CancelSubscriptionRequestBody,
        CancelSubscriptionRequestBodyTypedDict,
        CancelSubscriptionRequestTypedDict,
    )
    from .capability_requirement_status import CapabilityRequirementStatus
    from .capability_status import CapabilityStatus
    from .capability_status_reason import CapabilityStatusReason
    from .capture_mode import CaptureMode
    from .capture_mode_response import CaptureModeResponse
    from .capture_response import (
        CaptureResponse,
        CaptureResponseLinks,
        CaptureResponseLinksTypedDict,
        CaptureResponseSettlementAmount,
        CaptureResponseSettlementAmountTypedDict,
        CaptureResponseStatus,
        CaptureResponseTypedDict,
    )
    from .client_link_request import (
        ClientLinkRequest,
        ClientLinkRequestAddress,
        ClientLinkRequestAddressTypedDict,
        ClientLinkRequestTypedDict,
        Owner,
        OwnerTypedDict,
    )
    from .client_link_response import (
        ClientLinkResponse,
        ClientLinkResponseLinks,
        ClientLinkResponseLinksTypedDict,
        ClientLinkResponseTypedDict,
    )
    from .components_sub_totals import ComponentsSubTotals, ComponentsSubTotalsTypedDict
    from .create_captureop import CreateCaptureRequest, CreateCaptureRequestTypedDict
    from .create_client_linkop import (
        CreateClientLinkRequest,
        CreateClientLinkRequestTypedDict,
    )
    from .create_connect_balance_transferop import (
        CreateConnectBalanceTransferRequest,
        CreateConnectBalanceTransferRequestTypedDict,
    )
    from .create_customer_paymentop import (
        CreateCustomerPaymentRequest,
        CreateCustomerPaymentRequestTypedDict,
    )
    from .create_customerop import CreateCustomerRequest, CreateCustomerRequestTypedDict
    from .create_mandateop import CreateMandateRequest, CreateMandateRequestTypedDict
    from .create_payment_linkop import (
        CreatePaymentLinkApplicationFee,
        CreatePaymentLinkApplicationFeeTypedDict,
        CreatePaymentLinkRequest,
        CreatePaymentLinkRequestBody,
        CreatePaymentLinkRequestBodyTypedDict,
        CreatePaymentLinkRequestTypedDict,
    )
    from .create_paymentop import CreatePaymentRequest, CreatePaymentRequestTypedDict
    from .create_profileop import CreateProfileRequest, CreateProfileRequestTypedDict
    from .create_refundop import CreateRefundRequest, CreateRefundRequestTypedDict
    from .create_sales_invoiceop import (
        CreateSalesInvoiceRequest,
        CreateSalesInvoiceRequestTypedDict,
    )
    from .create_sessionop import CreateSessionRequest, CreateSessionRequestTypedDict
    from .create_subscriptionop import (
        CreateSubscriptionRequest,
        CreateSubscriptionRequestTypedDict,
    )
    from .create_webhook import (
        CreateWebhook,
        CreateWebhookLinks,
        CreateWebhookLinksTypedDict,
        CreateWebhookTypedDict,
    )
    from .create_webhookop import (
        CreateWebhookEventTypes,
        CreateWebhookEventTypesTypedDict,
        CreateWebhookRequest,
        CreateWebhookRequestBody,
        CreateWebhookRequestBodyTypedDict,
        CreateWebhookRequestTypedDict,
    )
    from .currencies import Currencies
    from .customer_response import (
        CustomerResponse,
        CustomerResponseLinks,
        CustomerResponseLinksTypedDict,
        CustomerResponseTypedDict,
    )
    from .delete_customerop import (
        DeleteCustomerRequest,
        DeleteCustomerRequestBody,
        DeleteCustomerRequestBodyTypedDict,
        DeleteCustomerRequestTypedDict,
    )
    from .delete_payment_linkop import (
        DeletePaymentLinkRequest,
        DeletePaymentLinkRequestBody,
        DeletePaymentLinkRequestBodyTypedDict,
        DeletePaymentLinkRequestTypedDict,
    )
    from .delete_profileop import DeleteProfileRequest, DeleteProfileRequestTypedDict
    from .delete_sales_invoiceop import (
        DeleteSalesInvoiceRequest,
        DeleteSalesInvoiceRequestTypedDict,
    )
    from .delete_values_sales_invoice import (
        DeleteValuesSalesInvoice,
        DeleteValuesSalesInvoiceTypedDict,
    )
    from .delete_webhookop import (
        DeleteWebhookRequest,
        DeleteWebhookRequestBody,
        DeleteWebhookRequestBodyTypedDict,
        DeleteWebhookRequestTypedDict,
    )
    from .entity_balance import (
        EntityBalance,
        EntityBalanceAvailableAmount,
        EntityBalanceAvailableAmountTypedDict,
        EntityBalanceCurrency,
        EntityBalanceLinks,
        EntityBalanceLinksTypedDict,
        EntityBalancePendingAmount,
        EntityBalancePendingAmountTypedDict,
        EntityBalanceStatus,
        EntityBalanceTransferDestination,
        EntityBalanceTransferDestinationTypedDict,
        EntityBalanceTransferFrequency,
        EntityBalanceTransferThreshold,
        EntityBalanceTransferThresholdTypedDict,
        EntityBalanceTypedDict,
    )
    from .entity_balance_report import (
        AvailableBalance,
        AvailableBalanceTypedDict,
        Capital,
        CapitalTypedDict,
        Chargebacks,
        ChargebacksTypedDict,
        Close,
        CloseTypedDict,
        Corrections,
        CorrectionsTypedDict,
        EntityBalanceReport,
        EntityBalanceReportLinks,
        EntityBalanceReportLinksTypedDict,
        EntityBalanceReportTypedDict,
        FeePrepayments,
        FeePrepaymentsTypedDict,
        Open,
        OpenTypedDict,
        Payments,
        PaymentsTypedDict,
        PendingBalance,
        PendingBalanceTypedDict,
        Refunds,
        RefundsTypedDict,
        Topups,
        TopupsTypedDict,
        Totals,
        TotalsTypedDict,
        Transfers,
        TransfersTypedDict,
    )
    from .entity_balance_transaction import (
        CanceledOutgoingTransfer,
        CanceledOutgoingTransferTypedDict,
        Capture,
        CaptureCommision,
        CaptureCommisionTypedDict,
        CaptureRollingReserveRelease,
        CaptureRollingReserveReleaseTypedDict,
        CaptureTypedDict,
        Chargeback,
        ChargebackCompensation,
        ChargebackCompensationTypedDict,
        ChargebackReversal,
        ChargebackReversalTypedDict,
        ChargebackTypedDict,
        Context,
        ContextTypedDict,
        DeductionDetails,
        DeductionDetailsTypedDict,
        EntityBalanceTransaction,
        EntityBalanceTransactionApplicationFee,
        EntityBalanceTransactionApplicationFeeTypedDict,
        EntityBalanceTransactionPayment,
        EntityBalanceTransactionPaymentTypedDict,
        EntityBalanceTransactionTypedDict,
        FailedPayment,
        FailedPaymentFee,
        FailedPaymentFeeTypedDict,
        FailedPaymentTypedDict,
        InvoiceCompensation,
        InvoiceCompensationTypedDict,
        ManagedFee,
        ManagedFeeTypedDict,
        OutgoingTransfer,
        OutgoingTransferTypedDict,
        PaymentCommission,
        PaymentCommissionTypedDict,
        PaymentFee,
        PaymentFeeTypedDict,
        PlatformPaymentChargeback,
        PlatformPaymentChargebackTypedDict,
        PlatformPaymentRefund,
        PlatformPaymentRefundTypedDict,
        PostPaymentSplitPayment,
        PostPaymentSplitPaymentTypedDict,
        Refund,
        RefundCompensation,
        RefundCompensationTypedDict,
        RefundTypedDict,
        ReimbursementFee,
        ReimbursementFeeTypedDict,
        ReturnedManagedFee,
        ReturnedManagedFeeTypedDict,
        ReturnedPlatformPaymentRefund,
        ReturnedPlatformPaymentRefundTypedDict,
        ReturnedRefund,
        ReturnedRefundCompensation,
        ReturnedRefundCompensationTypedDict,
        ReturnedRefundTypedDict,
        ReturnedTransfer,
        ReturnedTransferTypedDict,
        ReversedChargebackCompensation,
        ReversedChargebackCompensationTypedDict,
        ReversedPlatformPaymentChargeback,
        ReversedPlatformPaymentChargebackTypedDict,
        SplitPayment,
        SplitPaymentTypedDict,
        UnauthorizedDirectDebit,
        UnauthorizedDirectDebitTypedDict,
    )
    from .entity_balance_transfer import (
        EntityBalanceTransfer,
        EntityBalanceTransferTypedDict,
    )
    from .entity_balance_transfer_party import (
        EntityBalanceTransferParty,
        EntityBalanceTransferPartyTypedDict,
    )
    from .entity_balance_transfer_party_response import (
        EntityBalanceTransferPartyResponse,
        EntityBalanceTransferPartyResponseTypedDict,
    )
    from .entity_balance_transfer_response import (
        EntityBalanceTransferResponse,
        EntityBalanceTransferResponseStatusReason,
        EntityBalanceTransferResponseStatusReasonTypedDict,
        EntityBalanceTransferResponseTypedDict,
    )
    from .entity_capability import EntityCapability, EntityCapabilityTypedDict
    from .entity_capability_requirement import (
        EntityCapabilityRequirement,
        EntityCapabilityRequirementLinks,
        EntityCapabilityRequirementLinksTypedDict,
        EntityCapabilityRequirementTypedDict,
    )
    from .entity_capture import EntityCapture, EntityCaptureTypedDict
    from .entity_chargeback import (
        EntityChargeback,
        EntityChargebackLinks,
        EntityChargebackLinksTypedDict,
        EntityChargebackReason,
        EntityChargebackReasonTypedDict,
        EntityChargebackSettlementAmount,
        EntityChargebackSettlementAmountTypedDict,
        EntityChargebackTypedDict,
    )
    from .entity_customer import EntityCustomer, EntityCustomerTypedDict
    from .entity_event import (
        EntityEvent,
        EntityEventLinks,
        EntityEventLinksTypedDict,
        EntityEventTypedDict,
    )
    from .entity_invoice import (
        EntityInvoice,
        EntityInvoiceGrossAmount,
        EntityInvoiceGrossAmountTypedDict,
        EntityInvoiceLine,
        EntityInvoiceLineTypedDict,
        EntityInvoiceLinks,
        EntityInvoiceLinksTypedDict,
        EntityInvoiceNetAmount,
        EntityInvoiceNetAmountTypedDict,
        EntityInvoiceStatus,
        EntityInvoiceTypedDict,
        EntityInvoiceVatAmount,
        EntityInvoiceVatAmountTypedDict,
    )
    from .entity_method_get import (
        EntityMethodGet,
        EntityMethodGetID,
        EntityMethodGetImage,
        EntityMethodGetImageTypedDict,
        EntityMethodGetIssuer,
        EntityMethodGetIssuerImage,
        EntityMethodGetIssuerImageTypedDict,
        EntityMethodGetIssuerTypedDict,
        EntityMethodGetLinks,
        EntityMethodGetLinksTypedDict,
        EntityMethodGetMaximumAmount,
        EntityMethodGetMaximumAmountTypedDict,
        EntityMethodGetMinimumAmount,
        EntityMethodGetMinimumAmountTypedDict,
        EntityMethodGetTypedDict,
    )
    from .entity_onboarding_status import (
        EntityOnboardingStatus,
        EntityOnboardingStatusLinks,
        EntityOnboardingStatusLinksTypedDict,
        EntityOnboardingStatusStatus,
        EntityOnboardingStatusTypedDict,
    )
    from .entity_organization import (
        EntityOrganization,
        EntityOrganizationLinks,
        EntityOrganizationLinksTypedDict,
        EntityOrganizationLocale,
        EntityOrganizationTypedDict,
    )
    from .entity_payment_route import (
        EntityPaymentRoute,
        EntityPaymentRouteDestination,
        EntityPaymentRouteDestinationTypedDict,
        EntityPaymentRouteLinks,
        EntityPaymentRouteLinksTypedDict,
        EntityPaymentRouteTypedDict,
    )
    from .entity_payment_route_response import (
        EntityPaymentRouteResponse,
        EntityPaymentRouteResponseDestination,
        EntityPaymentRouteResponseDestinationTypedDict,
        EntityPaymentRouteResponseLinks,
        EntityPaymentRouteResponseLinksTypedDict,
        EntityPaymentRouteResponseTypedDict,
    )
    from .entity_permission import (
        EntityPermission,
        EntityPermissionLinks,
        EntityPermissionLinksTypedDict,
        EntityPermissionTypedDict,
    )
    from .entity_refund_response import (
        EntityRefundResponse,
        EntityRefundResponseExternalReference,
        EntityRefundResponseExternalReferenceTypedDict,
        EntityRefundResponseLinks,
        EntityRefundResponseLinksTypedDict,
        EntityRefundResponseRoutingReversal,
        EntityRefundResponseRoutingReversalTypedDict,
        EntityRefundResponseSettlementAmount,
        EntityRefundResponseSettlementAmountTypedDict,
        EntityRefundResponseSource,
        EntityRefundResponseSourceTypedDict,
        EntityRefundResponseStatus,
        EntityRefundResponseTypedDict,
    )
    from .entity_settlement import (
        EntitySettlement,
        EntitySettlementAmount,
        EntitySettlementAmountTypedDict,
        EntitySettlementCost,
        EntitySettlementCostTypedDict,
        EntitySettlementLinks,
        EntitySettlementLinksTypedDict,
        EntitySettlementPeriods,
        EntitySettlementPeriodsTypedDict,
        EntitySettlementRate,
        EntitySettlementRateTypedDict,
        EntitySettlementRevenue,
        EntitySettlementRevenueTypedDict,
        EntitySettlementStatus,
        EntitySettlementTypedDict,
    )
    from .entity_terminal import (
        EntityTerminal,
        EntityTerminalLinks,
        EntityTerminalLinksTypedDict,
        EntityTerminalStatus,
        EntityTerminalTypedDict,
    )
    from .entity_webhook import (
        EntityWebhook,
        EntityWebhookLinks,
        EntityWebhookLinksTypedDict,
        EntityWebhookTypedDict,
    )
    from .entity_webhook_event import (
        Embedded,
        EmbeddedTypedDict,
        Entity,
        EntityTypedDict,
        EntityWebhookEvent,
        EntityWebhookEventLinks,
        EntityWebhookEventLinksTypedDict,
        EntityWebhookEventTypedDict,
        EntityWebhookEventWebhookEventTypes,
    )
    from .error_response import (
        Documentation,
        DocumentationTypedDict,
        ErrorResponse,
        ErrorResponseData,
        ErrorsLinks,
        ErrorsLinksTypedDict,
    )
    from .get_balance_reportop import (
        GetBalanceReportGlobals,
        GetBalanceReportGlobalsTypedDict,
        GetBalanceReportRequest,
        GetBalanceReportRequestTypedDict,
    )
    from .get_balanceop import (
        GetBalanceGlobals,
        GetBalanceGlobalsTypedDict,
        GetBalanceRequest,
        GetBalanceRequestTypedDict,
    )
    from .get_captureop import (
        GetCaptureGlobals,
        GetCaptureGlobalsTypedDict,
        GetCaptureRequest,
        GetCaptureRequestTypedDict,
    )
    from .get_chargebackop import (
        GetChargebackGlobals,
        GetChargebackGlobalsTypedDict,
        GetChargebackRequest,
        GetChargebackRequestTypedDict,
    )
    from .get_clientop import (
        GetClientCommission,
        GetClientCommissionTypedDict,
        GetClientEmbedded,
        GetClientEmbeddedTypedDict,
        GetClientLinks,
        GetClientLinksTypedDict,
        GetClientRequest,
        GetClientRequestTypedDict,
        GetClientResponse,
        GetClientResponseTypedDict,
    )
    from .get_connect_balance_transferop import (
        GetConnectBalanceTransferGlobals,
        GetConnectBalanceTransferGlobalsTypedDict,
        GetConnectBalanceTransferRequest,
        GetConnectBalanceTransferRequestTypedDict,
    )
    from .get_current_organizationop import (
        GetCurrentOrganizationRequest,
        GetCurrentOrganizationRequestTypedDict,
    )
    from .get_current_profileop import (
        GetCurrentProfileRequest,
        GetCurrentProfileRequestTypedDict,
    )
    from .get_customerop import (
        GetCustomerGlobals,
        GetCustomerGlobalsTypedDict,
        GetCustomerLinks,
        GetCustomerLinksTypedDict,
        GetCustomerRequest,
        GetCustomerRequestTypedDict,
        GetCustomerResponse,
        GetCustomerResponseTypedDict,
    )
    from .get_invoiceop import GetInvoiceRequest, GetInvoiceRequestTypedDict
    from .get_mandateop import (
        GetMandateGlobals,
        GetMandateGlobalsTypedDict,
        GetMandateRequest,
        GetMandateRequestTypedDict,
    )
    from .get_methodop import (
        GetMethodGlobals,
        GetMethodGlobalsTypedDict,
        GetMethodRequest,
        GetMethodRequestTypedDict,
    )
    from .get_next_settlementop import (
        GetNextSettlementRequest,
        GetNextSettlementRequestTypedDict,
    )
    from .get_onboarding_statusop import (
        GetOnboardingStatusRequest,
        GetOnboardingStatusRequestTypedDict,
    )
    from .get_open_settlementop import (
        GetOpenSettlementRequest,
        GetOpenSettlementRequestTypedDict,
    )
    from .get_organizationop import (
        GetOrganizationGlobals,
        GetOrganizationGlobalsTypedDict,
        GetOrganizationRequest,
        GetOrganizationRequestTypedDict,
    )
    from .get_partner_statusop import (
        GetPartnerStatusLinks,
        GetPartnerStatusLinksTypedDict,
        GetPartnerStatusRequest,
        GetPartnerStatusRequestTypedDict,
        GetPartnerStatusResponse,
        GetPartnerStatusResponseTypedDict,
        PartnerType,
        UserAgentToken,
        UserAgentTokenTypedDict,
    )
    from .get_payment_link_paymentsop import (
        GetPaymentLinkPaymentsEmbedded,
        GetPaymentLinkPaymentsEmbeddedTypedDict,
        GetPaymentLinkPaymentsGlobals,
        GetPaymentLinkPaymentsGlobalsTypedDict,
        GetPaymentLinkPaymentsRequest,
        GetPaymentLinkPaymentsRequestTypedDict,
        GetPaymentLinkPaymentsResponse,
        GetPaymentLinkPaymentsResponseBody,
        GetPaymentLinkPaymentsResponseBodyTypedDict,
        GetPaymentLinkPaymentsResponseTypedDict,
    )
    from .get_payment_linkop import (
        GetPaymentLinkGlobals,
        GetPaymentLinkGlobalsTypedDict,
        GetPaymentLinkRequest,
        GetPaymentLinkRequestTypedDict,
    )
    from .get_paymentop import (
        GetPaymentGlobals,
        GetPaymentGlobalsTypedDict,
        GetPaymentRequest,
        GetPaymentRequestTypedDict,
    )
    from .get_permissionop import (
        GetPermissionGlobals,
        GetPermissionGlobalsTypedDict,
        GetPermissionRequest,
        GetPermissionRequestTypedDict,
    )
    from .get_primary_balanceop import (
        GetPrimaryBalanceRequest,
        GetPrimaryBalanceRequestTypedDict,
    )
    from .get_profileop import (
        GetProfileGlobals,
        GetProfileGlobalsTypedDict,
        GetProfileRequest,
        GetProfileRequestTypedDict,
    )
    from .get_refundop import (
        GetRefundGlobals,
        GetRefundGlobalsTypedDict,
        GetRefundRequest,
        GetRefundRequestTypedDict,
    )
    from .get_sales_invoiceop import (
        GetSalesInvoiceGlobals,
        GetSalesInvoiceGlobalsTypedDict,
        GetSalesInvoiceRequest,
        GetSalesInvoiceRequestTypedDict,
    )
    from .get_sessionop import GetSessionRequest, GetSessionRequestTypedDict
    from .get_settlementop import GetSettlementRequest, GetSettlementRequestTypedDict
    from .get_subscriptionop import (
        GetSubscriptionGlobals,
        GetSubscriptionGlobalsTypedDict,
        GetSubscriptionRequest,
        GetSubscriptionRequestTypedDict,
    )
    from .get_terminalop import (
        GetTerminalGlobals,
        GetTerminalGlobalsTypedDict,
        GetTerminalRequest,
        GetTerminalRequestTypedDict,
    )
    from .get_webhook_eventop import (
        GetWebhookEventGlobals,
        GetWebhookEventGlobalsTypedDict,
        GetWebhookEventRequest,
        GetWebhookEventRequestTypedDict,
    )
    from .get_webhookop import (
        GetWebhookGlobals,
        GetWebhookGlobalsTypedDict,
        GetWebhookRequest,
        GetWebhookRequestTypedDict,
    )
    from .line_categories import LineCategories
    from .line_categories_response import LineCategoriesResponse
    from .list_all_chargebacksop import (
        ListAllChargebacksEmbedded,
        ListAllChargebacksEmbeddedTypedDict,
        ListAllChargebacksGlobals,
        ListAllChargebacksGlobalsTypedDict,
        ListAllChargebacksRequest,
        ListAllChargebacksRequestTypedDict,
        ListAllChargebacksResponse,
        ListAllChargebacksResponseBody,
        ListAllChargebacksResponseBodyTypedDict,
        ListAllChargebacksResponseTypedDict,
    )
    from .list_all_methodsop import (
        ListAllMethodsEmbedded,
        ListAllMethodsEmbeddedTypedDict,
        ListAllMethodsGlobals,
        ListAllMethodsGlobalsTypedDict,
        ListAllMethodsLinks,
        ListAllMethodsLinksTypedDict,
        ListAllMethodsRequest,
        ListAllMethodsRequestTypedDict,
        ListAllMethodsResponse,
        ListAllMethodsResponseTypedDict,
    )
    from .list_all_refundsop import (
        ListAllRefundsEmbedded,
        ListAllRefundsEmbeddedTypedDict,
        ListAllRefundsGlobals,
        ListAllRefundsGlobalsTypedDict,
        ListAllRefundsRequest,
        ListAllRefundsRequestTypedDict,
        ListAllRefundsResponse,
        ListAllRefundsResponseBody,
        ListAllRefundsResponseBodyTypedDict,
        ListAllRefundsResponseTypedDict,
    )
    from .list_all_subscriptionsop import (
        ListAllSubscriptionsEmbedded,
        ListAllSubscriptionsEmbeddedTypedDict,
        ListAllSubscriptionsGlobals,
        ListAllSubscriptionsGlobalsTypedDict,
        ListAllSubscriptionsRequest,
        ListAllSubscriptionsRequestTypedDict,
        ListAllSubscriptionsResponse,
        ListAllSubscriptionsResponseBody,
        ListAllSubscriptionsResponseBodyTypedDict,
        ListAllSubscriptionsResponseTypedDict,
    )
    from .list_balance_transactionsop import (
        ListBalanceTransactionsEmbedded,
        ListBalanceTransactionsEmbeddedTypedDict,
        ListBalanceTransactionsGlobals,
        ListBalanceTransactionsGlobalsTypedDict,
        ListBalanceTransactionsRequest,
        ListBalanceTransactionsRequestTypedDict,
        ListBalanceTransactionsResponse,
        ListBalanceTransactionsResponseBody,
        ListBalanceTransactionsResponseBodyTypedDict,
        ListBalanceTransactionsResponseTypedDict,
    )
    from .list_balancesop import (
        ListBalancesEmbedded,
        ListBalancesEmbeddedTypedDict,
        ListBalancesGlobals,
        ListBalancesGlobalsTypedDict,
        ListBalancesRequest,
        ListBalancesRequestTypedDict,
        ListBalancesResponse,
        ListBalancesResponseBody,
        ListBalancesResponseBodyTypedDict,
        ListBalancesResponseTypedDict,
    )
    from .list_capabilitiesop import (
        ListCapabilitiesEmbedded,
        ListCapabilitiesEmbeddedTypedDict,
        ListCapabilitiesLinks,
        ListCapabilitiesLinksTypedDict,
        ListCapabilitiesRequest,
        ListCapabilitiesRequestTypedDict,
        ListCapabilitiesResponse,
        ListCapabilitiesResponseTypedDict,
    )
    from .list_capture_response import (
        ListCaptureResponse,
        ListCaptureResponseLinks,
        ListCaptureResponseLinksTypedDict,
        ListCaptureResponseSettlementAmount,
        ListCaptureResponseSettlementAmountTypedDict,
        ListCaptureResponseStatus,
        ListCaptureResponseTypedDict,
    )
    from .list_capturesop import (
        ListCapturesEmbedded,
        ListCapturesEmbeddedTypedDict,
        ListCapturesGlobals,
        ListCapturesGlobalsTypedDict,
        ListCapturesRequest,
        ListCapturesRequestTypedDict,
        ListCapturesResponse,
        ListCapturesResponseBody,
        ListCapturesResponseBodyTypedDict,
        ListCapturesResponseTypedDict,
    )
    from .list_chargebacksop import (
        ListChargebacksEmbedded,
        ListChargebacksEmbeddedTypedDict,
        ListChargebacksGlobals,
        ListChargebacksGlobalsTypedDict,
        ListChargebacksRequest,
        ListChargebacksRequestTypedDict,
        ListChargebacksResponse,
        ListChargebacksResponseBody,
        ListChargebacksResponseBodyTypedDict,
        ListChargebacksResponseTypedDict,
    )
    from .list_clientsop import (
        ClientEmbedded,
        ClientEmbeddedTypedDict,
        ListClientsClient,
        ListClientsClientTypedDict,
        ListClientsCommission,
        ListClientsCommissionTypedDict,
        ListClientsEmbedded,
        ListClientsEmbeddedTypedDict,
        ListClientsLinks,
        ListClientsLinksTypedDict,
        ListClientsRequest,
        ListClientsRequestTypedDict,
        ListClientsResponse,
        ListClientsResponseBody,
        ListClientsResponseBodyTypedDict,
        ListClientsResponseTypedDict,
    )
    from .list_connect_balance_transfersop import (
        ListConnectBalanceTransfersEmbedded,
        ListConnectBalanceTransfersEmbeddedTypedDict,
        ListConnectBalanceTransfersGlobals,
        ListConnectBalanceTransfersGlobalsTypedDict,
        ListConnectBalanceTransfersRequest,
        ListConnectBalanceTransfersRequestTypedDict,
        ListConnectBalanceTransfersResponse,
        ListConnectBalanceTransfersResponseBody,
        ListConnectBalanceTransfersResponseBodyTypedDict,
        ListConnectBalanceTransfersResponseTypedDict,
    )
    from .list_customer_paymentsop import (
        ListCustomerPaymentsEmbedded,
        ListCustomerPaymentsEmbeddedTypedDict,
        ListCustomerPaymentsGlobals,
        ListCustomerPaymentsGlobalsTypedDict,
        ListCustomerPaymentsRequest,
        ListCustomerPaymentsRequestTypedDict,
        ListCustomerPaymentsResponse,
        ListCustomerPaymentsResponseBody,
        ListCustomerPaymentsResponseBodyTypedDict,
        ListCustomerPaymentsResponseTypedDict,
    )
    from .list_customer_response import (
        ListCustomerResponse,
        ListCustomerResponseLinks,
        ListCustomerResponseLinksTypedDict,
        ListCustomerResponseTypedDict,
    )
    from .list_customersop import (
        ListCustomersEmbedded,
        ListCustomersEmbeddedTypedDict,
        ListCustomersGlobals,
        ListCustomersGlobalsTypedDict,
        ListCustomersRequest,
        ListCustomersRequestTypedDict,
        ListCustomersResponse,
        ListCustomersResponseBody,
        ListCustomersResponseBodyTypedDict,
        ListCustomersResponseTypedDict,
    )
    from .list_entity_balance import (
        ListEntityBalance,
        ListEntityBalanceAvailableAmount,
        ListEntityBalanceAvailableAmountTypedDict,
        ListEntityBalanceCurrency,
        ListEntityBalanceLinks,
        ListEntityBalanceLinksTypedDict,
        ListEntityBalancePendingAmount,
        ListEntityBalancePendingAmountTypedDict,
        ListEntityBalanceStatus,
        ListEntityBalanceTransferDestination,
        ListEntityBalanceTransferDestinationTypedDict,
        ListEntityBalanceTransferFrequency,
        ListEntityBalanceTransferThreshold,
        ListEntityBalanceTransferThresholdTypedDict,
        ListEntityBalanceTypedDict,
    )
    from .list_entity_chargeback import (
        ListEntityChargeback,
        ListEntityChargebackLinks,
        ListEntityChargebackLinksTypedDict,
        ListEntityChargebackReason,
        ListEntityChargebackReasonTypedDict,
        ListEntityChargebackSettlementAmount,
        ListEntityChargebackSettlementAmountTypedDict,
        ListEntityChargebackTypedDict,
    )
    from .list_entity_invoice import (
        ListEntityInvoice,
        ListEntityInvoiceGrossAmount,
        ListEntityInvoiceGrossAmountTypedDict,
        ListEntityInvoiceLine,
        ListEntityInvoiceLineTypedDict,
        ListEntityInvoiceLinks,
        ListEntityInvoiceLinksTypedDict,
        ListEntityInvoiceNetAmount,
        ListEntityInvoiceNetAmountTypedDict,
        ListEntityInvoiceStatus,
        ListEntityInvoiceTypedDict,
        ListEntityInvoiceVatAmount,
        ListEntityInvoiceVatAmountTypedDict,
    )
    from .list_entity_method import (
        ListEntityMethod,
        ListEntityMethodID,
        ListEntityMethodImage,
        ListEntityMethodImageTypedDict,
        ListEntityMethodIssuer,
        ListEntityMethodIssuerImage,
        ListEntityMethodIssuerImageTypedDict,
        ListEntityMethodIssuerTypedDict,
        ListEntityMethodLinks,
        ListEntityMethodLinksTypedDict,
        ListEntityMethodMaximumAmount,
        ListEntityMethodMaximumAmountTypedDict,
        ListEntityMethodMinimumAmount,
        ListEntityMethodMinimumAmountTypedDict,
        ListEntityMethodTypedDict,
    )
    from .list_entity_method_all import (
        ListEntityMethodAll,
        ListEntityMethodAllID,
        ListEntityMethodAllImage,
        ListEntityMethodAllImageTypedDict,
        ListEntityMethodAllIssuer,
        ListEntityMethodAllIssuerImage,
        ListEntityMethodAllIssuerImageTypedDict,
        ListEntityMethodAllIssuerTypedDict,
        ListEntityMethodAllLinks,
        ListEntityMethodAllLinksTypedDict,
        ListEntityMethodAllMaximumAmount,
        ListEntityMethodAllMaximumAmountTypedDict,
        ListEntityMethodAllMinimumAmount,
        ListEntityMethodAllMinimumAmountTypedDict,
        ListEntityMethodAllTypedDict,
        Pricing,
        PricingTypedDict,
    )
    from .list_entity_permission import (
        ListEntityPermission,
        ListEntityPermissionLinks,
        ListEntityPermissionLinksTypedDict,
        ListEntityPermissionTypedDict,
    )
    from .list_entity_refund import (
        ListEntityRefund,
        ListEntityRefundExternalReference,
        ListEntityRefundExternalReferenceTypedDict,
        ListEntityRefundLinks,
        ListEntityRefundLinksTypedDict,
        ListEntityRefundRoutingReversal,
        ListEntityRefundRoutingReversalTypedDict,
        ListEntityRefundSettlementAmount,
        ListEntityRefundSettlementAmountTypedDict,
        ListEntityRefundSource,
        ListEntityRefundSourceTypedDict,
        ListEntityRefundStatus,
        ListEntityRefundTypedDict,
    )
    from .list_entity_settlement import (
        ListEntitySettlement,
        ListEntitySettlementAmount,
        ListEntitySettlementAmountTypedDict,
        ListEntitySettlementCost,
        ListEntitySettlementCostTypedDict,
        ListEntitySettlementLinks,
        ListEntitySettlementLinksTypedDict,
        ListEntitySettlementPeriods,
        ListEntitySettlementPeriodsTypedDict,
        ListEntitySettlementRate,
        ListEntitySettlementRateTypedDict,
        ListEntitySettlementRevenue,
        ListEntitySettlementRevenueTypedDict,
        ListEntitySettlementStatus,
        ListEntitySettlementTypedDict,
    )
    from .list_entity_terminal import (
        ListEntityTerminal,
        ListEntityTerminalLinks,
        ListEntityTerminalLinksTypedDict,
        ListEntityTerminalStatus,
        ListEntityTerminalTypedDict,
    )
    from .list_entity_webhook import (
        ListEntityWebhook,
        ListEntityWebhookLinks,
        ListEntityWebhookLinksTypedDict,
        ListEntityWebhookTypedDict,
    )
    from .list_invoicesop import (
        ListInvoicesEmbedded,
        ListInvoicesEmbeddedTypedDict,
        ListInvoicesRequest,
        ListInvoicesRequestTypedDict,
        ListInvoicesResponse,
        ListInvoicesResponseBody,
        ListInvoicesResponseBodyTypedDict,
        ListInvoicesResponseTypedDict,
    )
    from .list_links import ListLinks, ListLinksTypedDict
    from .list_mandate_response import (
        ListMandateResponse,
        ListMandateResponseDetails,
        ListMandateResponseDetailsTypedDict,
        ListMandateResponseLinks,
        ListMandateResponseLinksTypedDict,
        ListMandateResponseStatus,
        ListMandateResponseTypedDict,
    )
    from .list_mandatesop import (
        ListMandatesEmbedded,
        ListMandatesEmbeddedTypedDict,
        ListMandatesGlobals,
        ListMandatesGlobalsTypedDict,
        ListMandatesRequest,
        ListMandatesRequestTypedDict,
        ListMandatesResponse,
        ListMandatesResponseBody,
        ListMandatesResponseBodyTypedDict,
        ListMandatesResponseTypedDict,
    )
    from .list_methodsop import (
        ListMethodsEmbedded,
        ListMethodsEmbeddedTypedDict,
        ListMethodsGlobals,
        ListMethodsGlobalsTypedDict,
        ListMethodsLinks,
        ListMethodsLinksTypedDict,
        ListMethodsRequest,
        ListMethodsRequestTypedDict,
        ListMethodsResponse,
        ListMethodsResponseTypedDict,
    )
    from .list_payment_linksop import (
        ListPaymentLinksEmbedded,
        ListPaymentLinksEmbeddedTypedDict,
        ListPaymentLinksGlobals,
        ListPaymentLinksGlobalsTypedDict,
        ListPaymentLinksRequest,
        ListPaymentLinksRequestTypedDict,
        ListPaymentLinksResponse,
        ListPaymentLinksResponseBody,
        ListPaymentLinksResponseBodyTypedDict,
        ListPaymentLinksResponseTypedDict,
    )
    from .list_payment_response import (
        ListPaymentResponse,
        ListPaymentResponseAmountCaptured,
        ListPaymentResponseAmountCapturedTypedDict,
        ListPaymentResponseAmountChargedBack,
        ListPaymentResponseAmountChargedBackTypedDict,
        ListPaymentResponseAmountRefunded,
        ListPaymentResponseAmountRefundedTypedDict,
        ListPaymentResponseAmountRemaining,
        ListPaymentResponseAmountRemainingTypedDict,
        ListPaymentResponseApplicationFee,
        ListPaymentResponseApplicationFeeTypedDict,
        ListPaymentResponseBillingAddress,
        ListPaymentResponseBillingAddressTypedDict,
        ListPaymentResponseDetails,
        ListPaymentResponseDetailsTypedDict,
        ListPaymentResponseLine,
        ListPaymentResponseLineTypedDict,
        ListPaymentResponseLinks,
        ListPaymentResponseLinksTypedDict,
        ListPaymentResponseQrCode,
        ListPaymentResponseQrCodeTypedDict,
        ListPaymentResponseReceipt,
        ListPaymentResponseReceiptTypedDict,
        ListPaymentResponseSettlementAmount,
        ListPaymentResponseSettlementAmountTypedDict,
        ListPaymentResponseStatus,
        ListPaymentResponseTypedDict,
    )
    from .list_paymentsop import (
        ListPaymentsEmbedded,
        ListPaymentsEmbeddedTypedDict,
        ListPaymentsGlobals,
        ListPaymentsGlobalsTypedDict,
        ListPaymentsRequest,
        ListPaymentsRequestTypedDict,
        ListPaymentsResponse,
        ListPaymentsResponseBody,
        ListPaymentsResponseBodyTypedDict,
        ListPaymentsResponseTypedDict,
    )
    from .list_permissionsop import (
        ListPermissionsEmbedded,
        ListPermissionsEmbeddedTypedDict,
        ListPermissionsLinks,
        ListPermissionsLinksTypedDict,
        ListPermissionsRequest,
        ListPermissionsRequestTypedDict,
        ListPermissionsResponse,
        ListPermissionsResponseTypedDict,
    )
    from .list_profile_response import (
        ListProfileResponse,
        ListProfileResponseLinks,
        ListProfileResponseLinksTypedDict,
        ListProfileResponseReview,
        ListProfileResponseReviewTypedDict,
        ListProfileResponseStatus,
        ListProfileResponseTypedDict,
    )
    from .list_profilesop import (
        ListProfilesEmbedded,
        ListProfilesEmbeddedTypedDict,
        ListProfilesRequest,
        ListProfilesRequestTypedDict,
        ListProfilesResponse,
        ListProfilesResponseBody,
        ListProfilesResponseBodyTypedDict,
        ListProfilesResponseTypedDict,
    )
    from .list_refundsop import (
        ListRefundsEmbedded,
        ListRefundsEmbeddedTypedDict,
        ListRefundsGlobals,
        ListRefundsGlobalsTypedDict,
        ListRefundsRequest,
        ListRefundsRequestTypedDict,
        ListRefundsResponse,
        ListRefundsResponseBody,
        ListRefundsResponseBodyTypedDict,
        ListRefundsResponseTypedDict,
    )
    from .list_route_get_response import (
        ListRouteGetResponse,
        ListRouteGetResponseDestination,
        ListRouteGetResponseDestinationTypedDict,
        ListRouteGetResponseLinks,
        ListRouteGetResponseLinksTypedDict,
        ListRouteGetResponseTypedDict,
    )
    from .list_sales_invoice_response import (
        ListSalesInvoiceResponse,
        ListSalesInvoiceResponseAmountDue,
        ListSalesInvoiceResponseAmountDueTypedDict,
        ListSalesInvoiceResponseDiscountedSubtotalAmount,
        ListSalesInvoiceResponseDiscountedSubtotalAmountTypedDict,
        ListSalesInvoiceResponseLinks,
        ListSalesInvoiceResponseLinksTypedDict,
        ListSalesInvoiceResponseMetadata,
        ListSalesInvoiceResponseMetadataTypedDict,
        ListSalesInvoiceResponseSubtotalAmount,
        ListSalesInvoiceResponseSubtotalAmountTypedDict,
        ListSalesInvoiceResponseTotalAmount,
        ListSalesInvoiceResponseTotalAmountTypedDict,
        ListSalesInvoiceResponseTotalVatAmount,
        ListSalesInvoiceResponseTotalVatAmountTypedDict,
        ListSalesInvoiceResponseTypedDict,
    )
    from .list_sales_invoicesop import (
        ListSalesInvoicesEmbedded,
        ListSalesInvoicesEmbeddedTypedDict,
        ListSalesInvoicesGlobals,
        ListSalesInvoicesGlobalsTypedDict,
        ListSalesInvoicesRequest,
        ListSalesInvoicesRequestTypedDict,
        ListSalesInvoicesResponse,
        ListSalesInvoicesResponseBody,
        ListSalesInvoicesResponseBodyTypedDict,
        ListSalesInvoicesResponseTypedDict,
    )
    from .list_settlement_capturesop import (
        ListSettlementCapturesEmbedded,
        ListSettlementCapturesEmbeddedTypedDict,
        ListSettlementCapturesGlobals,
        ListSettlementCapturesGlobalsTypedDict,
        ListSettlementCapturesRequest,
        ListSettlementCapturesRequestTypedDict,
        ListSettlementCapturesResponse,
        ListSettlementCapturesResponseBody,
        ListSettlementCapturesResponseBodyTypedDict,
        ListSettlementCapturesResponseTypedDict,
    )
    from .list_settlement_chargebacksop import (
        ListSettlementChargebacksEmbedded,
        ListSettlementChargebacksEmbeddedTypedDict,
        ListSettlementChargebacksGlobals,
        ListSettlementChargebacksGlobalsTypedDict,
        ListSettlementChargebacksRequest,
        ListSettlementChargebacksRequestTypedDict,
        ListSettlementChargebacksResponse,
        ListSettlementChargebacksResponseBody,
        ListSettlementChargebacksResponseBodyTypedDict,
        ListSettlementChargebacksResponseTypedDict,
    )
    from .list_settlement_paymentsop import (
        ListSettlementPaymentsEmbedded,
        ListSettlementPaymentsEmbeddedTypedDict,
        ListSettlementPaymentsGlobals,
        ListSettlementPaymentsGlobalsTypedDict,
        ListSettlementPaymentsRequest,
        ListSettlementPaymentsRequestTypedDict,
        ListSettlementPaymentsResponse,
        ListSettlementPaymentsResponseBody,
        ListSettlementPaymentsResponseBodyTypedDict,
        ListSettlementPaymentsResponseTypedDict,
    )
    from .list_settlement_refundsop import (
        ListSettlementRefundsEmbedded,
        ListSettlementRefundsEmbeddedTypedDict,
        ListSettlementRefundsGlobals,
        ListSettlementRefundsGlobalsTypedDict,
        ListSettlementRefundsRequest,
        ListSettlementRefundsRequestTypedDict,
        ListSettlementRefundsResponse,
        ListSettlementRefundsResponseBody,
        ListSettlementRefundsResponseBodyTypedDict,
        ListSettlementRefundsResponseTypedDict,
    )
    from .list_settlementsop import (
        ListSettlementsEmbedded,
        ListSettlementsEmbeddedTypedDict,
        ListSettlementsRequest,
        ListSettlementsRequestTypedDict,
        ListSettlementsResponse,
        ListSettlementsResponseBody,
        ListSettlementsResponseBodyTypedDict,
        ListSettlementsResponseTypedDict,
    )
    from .list_subscription_paymentsop import (
        ListSubscriptionPaymentsEmbedded,
        ListSubscriptionPaymentsEmbeddedTypedDict,
        ListSubscriptionPaymentsGlobals,
        ListSubscriptionPaymentsGlobalsTypedDict,
        ListSubscriptionPaymentsRequest,
        ListSubscriptionPaymentsRequestTypedDict,
        ListSubscriptionPaymentsResponse,
        ListSubscriptionPaymentsResponseBody,
        ListSubscriptionPaymentsResponseBodyTypedDict,
        ListSubscriptionPaymentsResponseTypedDict,
    )
    from .list_subscription_response import (
        ListSubscriptionResponse,
        ListSubscriptionResponseApplicationFee,
        ListSubscriptionResponseApplicationFeeTypedDict,
        ListSubscriptionResponseLinks,
        ListSubscriptionResponseLinksTypedDict,
        ListSubscriptionResponseStatus,
        ListSubscriptionResponseTypedDict,
    )
    from .list_subscriptionsop import (
        ListSubscriptionsEmbedded,
        ListSubscriptionsEmbeddedTypedDict,
        ListSubscriptionsGlobals,
        ListSubscriptionsGlobalsTypedDict,
        ListSubscriptionsRequest,
        ListSubscriptionsRequestTypedDict,
        ListSubscriptionsResponse,
        ListSubscriptionsResponseBody,
        ListSubscriptionsResponseBodyTypedDict,
        ListSubscriptionsResponseTypedDict,
    )
    from .list_terminalsop import (
        ListTerminalsEmbedded,
        ListTerminalsEmbeddedTypedDict,
        ListTerminalsGlobals,
        ListTerminalsGlobalsTypedDict,
        ListTerminalsRequest,
        ListTerminalsRequestTypedDict,
        ListTerminalsResponse,
        ListTerminalsResponseBody,
        ListTerminalsResponseBodyTypedDict,
        ListTerminalsResponseTypedDict,
    )
    from .list_webhooksop import (
        ListWebhooksEmbedded,
        ListWebhooksEmbeddedTypedDict,
        ListWebhooksGlobals,
        ListWebhooksGlobalsTypedDict,
        ListWebhooksRequest,
        ListWebhooksRequestTypedDict,
        ListWebhooksResponse,
        ListWebhooksResponseBody,
        ListWebhooksResponseBodyTypedDict,
        ListWebhooksResponseTypedDict,
    )
    from .locale import Locale
    from .locale_response import LocaleResponse
    from .mandate_details_card_label_response import MandateDetailsCardLabelResponse
    from .mandate_method import MandateMethod
    from .mandate_method_response import MandateMethodResponse
    from .mandate_request import MandateRequest, MandateRequestTypedDict
    from .mandate_response import (
        MandateResponse,
        MandateResponseDetails,
        MandateResponseDetailsTypedDict,
        MandateResponseLinks,
        MandateResponseLinksTypedDict,
        MandateResponseStatus,
        MandateResponseTypedDict,
    )
    from .metadata import Metadata, MetadataTypedDict
    from .method_enum import MethodEnum
    from .method_include_wallets_parameter import MethodIncludeWalletsParameter
    from .method_resource_parameter import MethodResourceParameter
    from .method_response import MethodResponse
    from .method_status import MethodStatus
    from .mode import Mode
    from .no_response_error import NoResponseError
    from .onboarding_vat_regulation import OnboardingVatRegulation
    from .organization_vat_regulation import OrganizationVatRegulation
    from .payment_address import PaymentAddress, PaymentAddressTypedDict
    from .payment_create_routeop import (
        PaymentCreateRouteRequest,
        PaymentCreateRouteRequestTypedDict,
    )
    from .payment_details_card_audition_response import (
        PaymentDetailsCardAuditionResponse,
    )
    from .payment_details_card_funding_response import PaymentDetailsCardFundingResponse
    from .payment_details_card_label_response import PaymentDetailsCardLabelResponse
    from .payment_details_card_security_response import (
        PaymentDetailsCardSecurityResponse,
    )
    from .payment_details_failure_reason_response import (
        PaymentDetailsFailureReasonResponse,
    )
    from .payment_details_fee_region_response import PaymentDetailsFeeRegionResponse
    from .payment_details_receipt_card_read_method_response import (
        PaymentDetailsReceiptCardReadMethodResponse,
    )
    from .payment_details_receipt_card_verification_method_response import (
        PaymentDetailsReceiptCardVerificationMethodResponse,
    )
    from .payment_details_seller_protection_response import (
        PaymentDetailsSellerProtectionResponse,
    )
    from .payment_details_wallet_response import PaymentDetailsWalletResponse
    from .payment_get_routeop import (
        PaymentGetRouteRequest,
        PaymentGetRouteRequestTypedDict,
    )
    from .payment_line_item import PaymentLineItem, PaymentLineItemTypedDict
    from .payment_line_item_response import (
        PaymentLineItemResponse,
        PaymentLineItemResponseTypedDict,
    )
    from .payment_line_type import PaymentLineType
    from .payment_line_type_response import PaymentLineTypeResponse
    from .payment_link_method import PaymentLinkMethod
    from .payment_link_method_response import PaymentLinkMethodResponse
    from .payment_link_response import (
        PaymentLinkResponse,
        PaymentLinkResponseApplicationFee,
        PaymentLinkResponseApplicationFeeTypedDict,
        PaymentLinkResponseLinks,
        PaymentLinkResponseLinksTypedDict,
        PaymentLinkResponseTypedDict,
    )
    from .payment_link_sequence_type import PaymentLinkSequenceType
    from .payment_link_sequence_type_response import PaymentLinkSequenceTypeResponse
    from .payment_list_routesop import (
        PaymentListRoutesEmbedded,
        PaymentListRoutesEmbeddedTypedDict,
        PaymentListRoutesGlobals,
        PaymentListRoutesGlobalsTypedDict,
        PaymentListRoutesLinks,
        PaymentListRoutesLinksTypedDict,
        PaymentListRoutesRequest,
        PaymentListRoutesRequestTypedDict,
        PaymentListRoutesResponse,
        PaymentListRoutesResponseTypedDict,
    )
    from .payment_method import PaymentMethod
    from .payment_request import (
        Company,
        CompanyTypedDict,
        Method,
        MethodTypedDict,
        PaymentRequest,
        PaymentRequestApplicationFee,
        PaymentRequestApplicationFeeTypedDict,
        PaymentRequestBillingAddress,
        PaymentRequestBillingAddressTypedDict,
        PaymentRequestLine,
        PaymentRequestLineTypedDict,
        PaymentRequestTypedDict,
    )
    from .payment_response import (
        PaymentResponse,
        PaymentResponseAmountCaptured,
        PaymentResponseAmountCapturedTypedDict,
        PaymentResponseAmountChargedBack,
        PaymentResponseAmountChargedBackTypedDict,
        PaymentResponseAmountRefunded,
        PaymentResponseAmountRefundedTypedDict,
        PaymentResponseAmountRemaining,
        PaymentResponseAmountRemainingTypedDict,
        PaymentResponseApplicationFee,
        PaymentResponseApplicationFeeTypedDict,
        PaymentResponseBillingAddress,
        PaymentResponseBillingAddressTypedDict,
        PaymentResponseDetails,
        PaymentResponseDetailsTypedDict,
        PaymentResponseLine,
        PaymentResponseLineTypedDict,
        PaymentResponseLinks,
        PaymentResponseLinksTypedDict,
        PaymentResponseQrCode,
        PaymentResponseQrCodeTypedDict,
        PaymentResponseReceipt,
        PaymentResponseReceiptTypedDict,
        PaymentResponseSettlementAmount,
        PaymentResponseSettlementAmountTypedDict,
        PaymentResponseStatus,
        PaymentResponseTypedDict,
    )
    from .profile_request import ProfileRequest, ProfileRequestTypedDict
    from .profile_response import (
        ProfileResponse,
        ProfileResponseLinks,
        ProfileResponseLinksTypedDict,
        ProfileResponseReview,
        ProfileResponseReviewTypedDict,
        ProfileResponseStatus,
        ProfileResponseTypedDict,
    )
    from .profile_review_status_response import ProfileReviewStatusResponse
    from .recurring_line_item import RecurringLineItem, RecurringLineItemTypedDict
    from .refund_external_reference_type import RefundExternalReferenceType
    from .refund_external_reference_type_response import (
        RefundExternalReferenceTypeResponse,
    )
    from .refund_request import (
        RefundRequest,
        RefundRequestExternalReference,
        RefundRequestExternalReferenceTypedDict,
        RefundRequestRoutingReversal,
        RefundRequestRoutingReversalTypedDict,
        RefundRequestSource,
        RefundRequestSourceTypedDict,
        RefundRequestTypedDict,
        Type,
    )
    from .release_authorizationop import (
        ReleaseAuthorizationRequest,
        ReleaseAuthorizationRequestBody,
        ReleaseAuthorizationRequestBodyTypedDict,
        ReleaseAuthorizationRequestTypedDict,
    )
    from .request_apple_pay_payment_sessionop import (
        RequestApplePayPaymentSessionRequest,
        RequestApplePayPaymentSessionRequestBody,
        RequestApplePayPaymentSessionRequestBodyTypedDict,
        RequestApplePayPaymentSessionRequestTypedDict,
    )
    from .responsevalidationerror import ResponseValidationError
    from .revoke_mandateop import (
        RevokeMandateRequest,
        RevokeMandateRequestBody,
        RevokeMandateRequestBodyTypedDict,
        RevokeMandateRequestTypedDict,
    )
    from .route_create_request import (
        RouteCreateRequest,
        RouteCreateRequestDestination,
        RouteCreateRequestDestinationTypedDict,
        RouteCreateRequestTypedDict,
    )
    from .route_create_response import (
        RouteCreateResponse,
        RouteCreateResponseDestination,
        RouteCreateResponseDestinationTypedDict,
        RouteCreateResponseLinks,
        RouteCreateResponseLinksTypedDict,
        RouteCreateResponseTypedDict,
    )
    from .route_destination_type import RouteDestinationType
    from .route_destination_type_response import RouteDestinationTypeResponse
    from .route_get_response import (
        RouteGetResponse,
        RouteGetResponseDestination,
        RouteGetResponseDestinationTypedDict,
        RouteGetResponseLinks,
        RouteGetResponseLinksTypedDict,
        RouteGetResponseTypedDict,
    )
    from .sales_invoice_discount import (
        SalesInvoiceDiscount,
        SalesInvoiceDiscountTypedDict,
    )
    from .sales_invoice_discount_response import (
        SalesInvoiceDiscountResponse,
        SalesInvoiceDiscountResponseTypedDict,
    )
    from .sales_invoice_discount_type import SalesInvoiceDiscountType
    from .sales_invoice_discount_type_response import SalesInvoiceDiscountTypeResponse
    from .sales_invoice_email_details import (
        SalesInvoiceEmailDetails,
        SalesInvoiceEmailDetailsTypedDict,
    )
    from .sales_invoice_line_item import (
        SalesInvoiceLineItem,
        SalesInvoiceLineItemTypedDict,
    )
    from .sales_invoice_line_item_response import (
        SalesInvoiceLineItemResponse,
        SalesInvoiceLineItemResponseTypedDict,
    )
    from .sales_invoice_payment_details import (
        SalesInvoicePaymentDetails,
        SalesInvoicePaymentDetailsTypedDict,
    )
    from .sales_invoice_payment_details_response import (
        SalesInvoicePaymentDetailsResponse,
        SalesInvoicePaymentDetailsResponseTypedDict,
    )
    from .sales_invoice_payment_details_source import SalesInvoicePaymentDetailsSource
    from .sales_invoice_payment_details_source_response import (
        SalesInvoicePaymentDetailsSourceResponse,
    )
    from .sales_invoice_payment_term import SalesInvoicePaymentTerm
    from .sales_invoice_payment_term_response import SalesInvoicePaymentTermResponse
    from .sales_invoice_recipient import (
        SalesInvoiceRecipient,
        SalesInvoiceRecipientTypedDict,
    )
    from .sales_invoice_recipient_locale import SalesInvoiceRecipientLocale
    from .sales_invoice_recipient_locale_response import (
        SalesInvoiceRecipientLocaleResponse,
    )
    from .sales_invoice_recipient_response import (
        SalesInvoiceRecipientResponse,
        SalesInvoiceRecipientResponseTypedDict,
    )
    from .sales_invoice_recipient_type import SalesInvoiceRecipientType
    from .sales_invoice_recipient_type_response import SalesInvoiceRecipientTypeResponse
    from .sales_invoice_request import (
        SalesInvoiceRequest,
        SalesInvoiceRequestMetadata,
        SalesInvoiceRequestMetadataTypedDict,
        SalesInvoiceRequestTypedDict,
    )
    from .sales_invoice_response import (
        SalesInvoiceResponse,
        SalesInvoiceResponseAmountDue,
        SalesInvoiceResponseAmountDueTypedDict,
        SalesInvoiceResponseDiscountedSubtotalAmount,
        SalesInvoiceResponseDiscountedSubtotalAmountTypedDict,
        SalesInvoiceResponseLinks,
        SalesInvoiceResponseLinksTypedDict,
        SalesInvoiceResponseMetadata,
        SalesInvoiceResponseMetadataTypedDict,
        SalesInvoiceResponseSubtotalAmount,
        SalesInvoiceResponseSubtotalAmountTypedDict,
        SalesInvoiceResponseTotalAmount,
        SalesInvoiceResponseTotalAmountTypedDict,
        SalesInvoiceResponseTotalVatAmount,
        SalesInvoiceResponseTotalVatAmountTypedDict,
        SalesInvoiceResponseTypedDict,
    )
    from .sales_invoice_status import SalesInvoiceStatus
    from .sales_invoice_status_response import SalesInvoiceStatusResponse
    from .sales_invoice_vat_mode import SalesInvoiceVatMode
    from .sales_invoice_vat_mode_response import SalesInvoiceVatModeResponse
    from .sales_invoice_vat_scheme import SalesInvoiceVatScheme
    from .sales_invoice_vat_scheme_response import SalesInvoiceVatSchemeResponse
    from .security import Security, SecurityTypedDict
    from .sequence_type import SequenceType
    from .sequence_type_response import SequenceTypeResponse
    from .session_line_item import SessionLineItem, SessionLineItemTypedDict
    from .session_line_item_response import (
        SessionLineItemResponse,
        SessionLineItemResponseTypedDict,
    )
    from .session_request import (
        SessionRequest,
        SessionRequestPayment,
        SessionRequestPaymentTypedDict,
        SessionRequestTypedDict,
    )
    from .session_response import (
        SessionResponse,
        SessionResponseLinks,
        SessionResponseLinksTypedDict,
        SessionResponsePayment,
        SessionResponsePaymentTypedDict,
        SessionResponseStatus,
        SessionResponseTypedDict,
    )
    from .session_sequence_type import SessionSequenceType
    from .session_sequence_type_response import SessionSequenceTypeResponse
    from .sorting import Sorting
    from .status_reason import Code, StatusReason, StatusReasonTypedDict
    from .sub_group import SubGroup, SubGroupTypedDict
    from .sub_totals import SubTotals, SubTotalsTypedDict
    from .submit_onboarding_dataop import (
        Organization,
        OrganizationTypedDict,
        Profile,
        ProfileTypedDict,
        SubmitOnboardingDataRequest,
        SubmitOnboardingDataRequestBody,
        SubmitOnboardingDataRequestBodyTypedDict,
        SubmitOnboardingDataRequestTypedDict,
    )
    from .subscription_method import SubscriptionMethod
    from .subscription_method_response import SubscriptionMethodResponse
    from .subscription_request import (
        SubscriptionRequest,
        SubscriptionRequestApplicationFee,
        SubscriptionRequestApplicationFeeTypedDict,
        SubscriptionRequestTypedDict,
    )
    from .subscription_response import (
        SubscriptionResponse,
        SubscriptionResponseApplicationFee,
        SubscriptionResponseApplicationFeeTypedDict,
        SubscriptionResponseLinks,
        SubscriptionResponseLinksTypedDict,
        SubscriptionResponseStatus,
        SubscriptionResponseTypedDict,
    )
    from .terminal_brand import TerminalBrand
    from .terminal_model import TerminalModel
    from .test_webhookop import (
        TestWebhookRequest,
        TestWebhookRequestBody,
        TestWebhookRequestBodyTypedDict,
        TestWebhookRequestTypedDict,
    )
    from .update_customerop import (
        UpdateCustomerRequest,
        UpdateCustomerRequestBody,
        UpdateCustomerRequestBodyTypedDict,
        UpdateCustomerRequestTypedDict,
    )
    from .update_payment_linkop import (
        UpdatePaymentLinkRequest,
        UpdatePaymentLinkRequestBody,
        UpdatePaymentLinkRequestBodyTypedDict,
        UpdatePaymentLinkRequestTypedDict,
    )
    from .update_paymentop import (
        UpdatePaymentRequest,
        UpdatePaymentRequestBody,
        UpdatePaymentRequestBodyTypedDict,
        UpdatePaymentRequestTypedDict,
    )
    from .update_profileop import (
        UpdateProfileRequest,
        UpdateProfileRequestBody,
        UpdateProfileRequestBodyTypedDict,
        UpdateProfileRequestTypedDict,
    )
    from .update_sales_invoiceop import (
        UpdateSalesInvoiceRequest,
        UpdateSalesInvoiceRequestBody,
        UpdateSalesInvoiceRequestBodyTypedDict,
        UpdateSalesInvoiceRequestTypedDict,
    )
    from .update_subscriptionop import (
        UpdateSubscriptionRequest,
        UpdateSubscriptionRequestBody,
        UpdateSubscriptionRequestBodyTypedDict,
        UpdateSubscriptionRequestTypedDict,
    )
    from .update_webhookop import (
        UpdateWebhookEventTypes,
        UpdateWebhookEventTypesTypedDict,
        UpdateWebhookRequest,
        UpdateWebhookRequestBody,
        UpdateWebhookRequestBodyTypedDict,
        UpdateWebhookRequestTypedDict,
    )
    from .url import URL, URLTypedDict
    from .url_nullable import URLNullable, URLNullableTypedDict
    from .webhook_event_types import WebhookEventTypes
    from .webhook_status import WebhookStatus
    from . import internal

__all__ = [
    "APIError",
    "Address",
    "AddressTypedDict",
    "Amount",
    "AmountNullable",
    "AmountNullableTypedDict",
    "AmountTypedDict",
    "AvailableBalance",
    "AvailableBalanceTypedDict",
    "BalanceCardAudience",
    "BalanceCardIssuer",
    "BalanceCardRegion",
    "BalanceFeeType",
    "BalancePrepaymentPartType",
    "BalanceReportGrouping",
    "BalanceTransactionType",
    "BalanceTransferCategory",
    "BalanceTransferCategoryResponse",
    "BalanceTransferDestinationType",
    "BalanceTransferPartyType",
    "BalanceTransferPartyTypeResponse",
    "BalanceTransferStatus",
    "BalanceTransferStatusReasonResponse",
    "BillingAddress",
    "BillingAddressTypedDict",
    "CancelPaymentRequest",
    "CancelPaymentRequestBody",
    "CancelPaymentRequestBodyTypedDict",
    "CancelPaymentRequestTypedDict",
    "CancelRefundGlobals",
    "CancelRefundGlobalsTypedDict",
    "CancelRefundRequest",
    "CancelRefundRequestTypedDict",
    "CancelSubscriptionRequest",
    "CancelSubscriptionRequestBody",
    "CancelSubscriptionRequestBodyTypedDict",
    "CancelSubscriptionRequestTypedDict",
    "CanceledOutgoingTransfer",
    "CanceledOutgoingTransferTypedDict",
    "CapabilityRequirementStatus",
    "CapabilityStatus",
    "CapabilityStatusReason",
    "Capital",
    "CapitalTypedDict",
    "Capture",
    "CaptureCommision",
    "CaptureCommisionTypedDict",
    "CaptureMode",
    "CaptureModeResponse",
    "CaptureResponse",
    "CaptureResponseLinks",
    "CaptureResponseLinksTypedDict",
    "CaptureResponseSettlementAmount",
    "CaptureResponseSettlementAmountTypedDict",
    "CaptureResponseStatus",
    "CaptureResponseTypedDict",
    "CaptureRollingReserveRelease",
    "CaptureRollingReserveReleaseTypedDict",
    "CaptureTypedDict",
    "Chargeback",
    "ChargebackCompensation",
    "ChargebackCompensationTypedDict",
    "ChargebackReversal",
    "ChargebackReversalTypedDict",
    "ChargebackTypedDict",
    "Chargebacks",
    "ChargebacksTypedDict",
    "ClientEmbedded",
    "ClientEmbeddedTypedDict",
    "ClientError",
    "ClientLinkRequest",
    "ClientLinkRequestAddress",
    "ClientLinkRequestAddressTypedDict",
    "ClientLinkRequestTypedDict",
    "ClientLinkResponse",
    "ClientLinkResponseLinks",
    "ClientLinkResponseLinksTypedDict",
    "ClientLinkResponseTypedDict",
    "Close",
    "CloseTypedDict",
    "Code",
    "Company",
    "CompanyTypedDict",
    "ComponentsSubTotals",
    "ComponentsSubTotalsTypedDict",
    "Context",
    "ContextTypedDict",
    "Corrections",
    "CorrectionsTypedDict",
    "CreateCaptureRequest",
    "CreateCaptureRequestTypedDict",
    "CreateClientLinkRequest",
    "CreateClientLinkRequestTypedDict",
    "CreateConnectBalanceTransferRequest",
    "CreateConnectBalanceTransferRequestTypedDict",
    "CreateCustomerPaymentRequest",
    "CreateCustomerPaymentRequestTypedDict",
    "CreateCustomerRequest",
    "CreateCustomerRequestTypedDict",
    "CreateMandateRequest",
    "CreateMandateRequestTypedDict",
    "CreatePaymentLinkApplicationFee",
    "CreatePaymentLinkApplicationFeeTypedDict",
    "CreatePaymentLinkRequest",
    "CreatePaymentLinkRequestBody",
    "CreatePaymentLinkRequestBodyTypedDict",
    "CreatePaymentLinkRequestTypedDict",
    "CreatePaymentRequest",
    "CreatePaymentRequestTypedDict",
    "CreateProfileRequest",
    "CreateProfileRequestTypedDict",
    "CreateRefundRequest",
    "CreateRefundRequestTypedDict",
    "CreateSalesInvoiceRequest",
    "CreateSalesInvoiceRequestTypedDict",
    "CreateSessionRequest",
    "CreateSessionRequestTypedDict",
    "CreateSubscriptionRequest",
    "CreateSubscriptionRequestTypedDict",
    "CreateWebhook",
    "CreateWebhookEventTypes",
    "CreateWebhookEventTypesTypedDict",
    "CreateWebhookLinks",
    "CreateWebhookLinksTypedDict",
    "CreateWebhookRequest",
    "CreateWebhookRequestBody",
    "CreateWebhookRequestBodyTypedDict",
    "CreateWebhookRequestTypedDict",
    "CreateWebhookTypedDict",
    "Currencies",
    "CustomerResponse",
    "CustomerResponseLinks",
    "CustomerResponseLinksTypedDict",
    "CustomerResponseTypedDict",
    "DeductionDetails",
    "DeductionDetailsTypedDict",
    "DeleteCustomerRequest",
    "DeleteCustomerRequestBody",
    "DeleteCustomerRequestBodyTypedDict",
    "DeleteCustomerRequestTypedDict",
    "DeletePaymentLinkRequest",
    "DeletePaymentLinkRequestBody",
    "DeletePaymentLinkRequestBodyTypedDict",
    "DeletePaymentLinkRequestTypedDict",
    "DeleteProfileRequest",
    "DeleteProfileRequestTypedDict",
    "DeleteSalesInvoiceRequest",
    "DeleteSalesInvoiceRequestTypedDict",
    "DeleteValuesSalesInvoice",
    "DeleteValuesSalesInvoiceTypedDict",
    "DeleteWebhookRequest",
    "DeleteWebhookRequestBody",
    "DeleteWebhookRequestBodyTypedDict",
    "DeleteWebhookRequestTypedDict",
    "Documentation",
    "DocumentationTypedDict",
    "Embedded",
    "EmbeddedTypedDict",
    "Entity",
    "EntityBalance",
    "EntityBalanceAvailableAmount",
    "EntityBalanceAvailableAmountTypedDict",
    "EntityBalanceCurrency",
    "EntityBalanceLinks",
    "EntityBalanceLinksTypedDict",
    "EntityBalancePendingAmount",
    "EntityBalancePendingAmountTypedDict",
    "EntityBalanceReport",
    "EntityBalanceReportLinks",
    "EntityBalanceReportLinksTypedDict",
    "EntityBalanceReportTypedDict",
    "EntityBalanceStatus",
    "EntityBalanceTransaction",
    "EntityBalanceTransactionApplicationFee",
    "EntityBalanceTransactionApplicationFeeTypedDict",
    "EntityBalanceTransactionPayment",
    "EntityBalanceTransactionPaymentTypedDict",
    "EntityBalanceTransactionTypedDict",
    "EntityBalanceTransfer",
    "EntityBalanceTransferDestination",
    "EntityBalanceTransferDestinationTypedDict",
    "EntityBalanceTransferFrequency",
    "EntityBalanceTransferParty",
    "EntityBalanceTransferPartyResponse",
    "EntityBalanceTransferPartyResponseTypedDict",
    "EntityBalanceTransferPartyTypedDict",
    "EntityBalanceTransferResponse",
    "EntityBalanceTransferResponseStatusReason",
    "EntityBalanceTransferResponseStatusReasonTypedDict",
    "EntityBalanceTransferResponseTypedDict",
    "EntityBalanceTransferThreshold",
    "EntityBalanceTransferThresholdTypedDict",
    "EntityBalanceTransferTypedDict",
    "EntityBalanceTypedDict",
    "EntityCapability",
    "EntityCapabilityRequirement",
    "EntityCapabilityRequirementLinks",
    "EntityCapabilityRequirementLinksTypedDict",
    "EntityCapabilityRequirementTypedDict",
    "EntityCapabilityTypedDict",
    "EntityCapture",
    "EntityCaptureTypedDict",
    "EntityChargeback",
    "EntityChargebackLinks",
    "EntityChargebackLinksTypedDict",
    "EntityChargebackReason",
    "EntityChargebackReasonTypedDict",
    "EntityChargebackSettlementAmount",
    "EntityChargebackSettlementAmountTypedDict",
    "EntityChargebackTypedDict",
    "EntityCustomer",
    "EntityCustomerTypedDict",
    "EntityEvent",
    "EntityEventLinks",
    "EntityEventLinksTypedDict",
    "EntityEventTypedDict",
    "EntityInvoice",
    "EntityInvoiceGrossAmount",
    "EntityInvoiceGrossAmountTypedDict",
    "EntityInvoiceLine",
    "EntityInvoiceLineTypedDict",
    "EntityInvoiceLinks",
    "EntityInvoiceLinksTypedDict",
    "EntityInvoiceNetAmount",
    "EntityInvoiceNetAmountTypedDict",
    "EntityInvoiceStatus",
    "EntityInvoiceTypedDict",
    "EntityInvoiceVatAmount",
    "EntityInvoiceVatAmountTypedDict",
    "EntityMethodGet",
    "EntityMethodGetID",
    "EntityMethodGetImage",
    "EntityMethodGetImageTypedDict",
    "EntityMethodGetIssuer",
    "EntityMethodGetIssuerImage",
    "EntityMethodGetIssuerImageTypedDict",
    "EntityMethodGetIssuerTypedDict",
    "EntityMethodGetLinks",
    "EntityMethodGetLinksTypedDict",
    "EntityMethodGetMaximumAmount",
    "EntityMethodGetMaximumAmountTypedDict",
    "EntityMethodGetMinimumAmount",
    "EntityMethodGetMinimumAmountTypedDict",
    "EntityMethodGetTypedDict",
    "EntityOnboardingStatus",
    "EntityOnboardingStatusLinks",
    "EntityOnboardingStatusLinksTypedDict",
    "EntityOnboardingStatusStatus",
    "EntityOnboardingStatusTypedDict",
    "EntityOrganization",
    "EntityOrganizationLinks",
    "EntityOrganizationLinksTypedDict",
    "EntityOrganizationLocale",
    "EntityOrganizationTypedDict",
    "EntityPaymentRoute",
    "EntityPaymentRouteDestination",
    "EntityPaymentRouteDestinationTypedDict",
    "EntityPaymentRouteLinks",
    "EntityPaymentRouteLinksTypedDict",
    "EntityPaymentRouteResponse",
    "EntityPaymentRouteResponseDestination",
    "EntityPaymentRouteResponseDestinationTypedDict",
    "EntityPaymentRouteResponseLinks",
    "EntityPaymentRouteResponseLinksTypedDict",
    "EntityPaymentRouteResponseTypedDict",
    "EntityPaymentRouteTypedDict",
    "EntityPermission",
    "EntityPermissionLinks",
    "EntityPermissionLinksTypedDict",
    "EntityPermissionTypedDict",
    "EntityRefundResponse",
    "EntityRefundResponseExternalReference",
    "EntityRefundResponseExternalReferenceTypedDict",
    "EntityRefundResponseLinks",
    "EntityRefundResponseLinksTypedDict",
    "EntityRefundResponseRoutingReversal",
    "EntityRefundResponseRoutingReversalTypedDict",
    "EntityRefundResponseSettlementAmount",
    "EntityRefundResponseSettlementAmountTypedDict",
    "EntityRefundResponseSource",
    "EntityRefundResponseSourceTypedDict",
    "EntityRefundResponseStatus",
    "EntityRefundResponseTypedDict",
    "EntitySettlement",
    "EntitySettlementAmount",
    "EntitySettlementAmountTypedDict",
    "EntitySettlementCost",
    "EntitySettlementCostTypedDict",
    "EntitySettlementLinks",
    "EntitySettlementLinksTypedDict",
    "EntitySettlementPeriods",
    "EntitySettlementPeriodsTypedDict",
    "EntitySettlementRate",
    "EntitySettlementRateTypedDict",
    "EntitySettlementRevenue",
    "EntitySettlementRevenueTypedDict",
    "EntitySettlementStatus",
    "EntitySettlementTypedDict",
    "EntityTerminal",
    "EntityTerminalLinks",
    "EntityTerminalLinksTypedDict",
    "EntityTerminalStatus",
    "EntityTerminalTypedDict",
    "EntityTypedDict",
    "EntityWebhook",
    "EntityWebhookEvent",
    "EntityWebhookEventLinks",
    "EntityWebhookEventLinksTypedDict",
    "EntityWebhookEventTypedDict",
    "EntityWebhookEventWebhookEventTypes",
    "EntityWebhookLinks",
    "EntityWebhookLinksTypedDict",
    "EntityWebhookTypedDict",
    "ErrorResponse",
    "ErrorResponseData",
    "ErrorsLinks",
    "ErrorsLinksTypedDict",
    "FailedPayment",
    "FailedPaymentFee",
    "FailedPaymentFeeTypedDict",
    "FailedPaymentTypedDict",
    "FeePrepayments",
    "FeePrepaymentsTypedDict",
    "GetBalanceGlobals",
    "GetBalanceGlobalsTypedDict",
    "GetBalanceReportGlobals",
    "GetBalanceReportGlobalsTypedDict",
    "GetBalanceReportRequest",
    "GetBalanceReportRequestTypedDict",
    "GetBalanceRequest",
    "GetBalanceRequestTypedDict",
    "GetCaptureGlobals",
    "GetCaptureGlobalsTypedDict",
    "GetCaptureRequest",
    "GetCaptureRequestTypedDict",
    "GetChargebackGlobals",
    "GetChargebackGlobalsTypedDict",
    "GetChargebackRequest",
    "GetChargebackRequestTypedDict",
    "GetClientCommission",
    "GetClientCommissionTypedDict",
    "GetClientEmbedded",
    "GetClientEmbeddedTypedDict",
    "GetClientLinks",
    "GetClientLinksTypedDict",
    "GetClientRequest",
    "GetClientRequestTypedDict",
    "GetClientResponse",
    "GetClientResponseTypedDict",
    "GetConnectBalanceTransferGlobals",
    "GetConnectBalanceTransferGlobalsTypedDict",
    "GetConnectBalanceTransferRequest",
    "GetConnectBalanceTransferRequestTypedDict",
    "GetCurrentOrganizationRequest",
    "GetCurrentOrganizationRequestTypedDict",
    "GetCurrentProfileRequest",
    "GetCurrentProfileRequestTypedDict",
    "GetCustomerGlobals",
    "GetCustomerGlobalsTypedDict",
    "GetCustomerLinks",
    "GetCustomerLinksTypedDict",
    "GetCustomerRequest",
    "GetCustomerRequestTypedDict",
    "GetCustomerResponse",
    "GetCustomerResponseTypedDict",
    "GetInvoiceRequest",
    "GetInvoiceRequestTypedDict",
    "GetMandateGlobals",
    "GetMandateGlobalsTypedDict",
    "GetMandateRequest",
    "GetMandateRequestTypedDict",
    "GetMethodGlobals",
    "GetMethodGlobalsTypedDict",
    "GetMethodRequest",
    "GetMethodRequestTypedDict",
    "GetNextSettlementRequest",
    "GetNextSettlementRequestTypedDict",
    "GetOnboardingStatusRequest",
    "GetOnboardingStatusRequestTypedDict",
    "GetOpenSettlementRequest",
    "GetOpenSettlementRequestTypedDict",
    "GetOrganizationGlobals",
    "GetOrganizationGlobalsTypedDict",
    "GetOrganizationRequest",
    "GetOrganizationRequestTypedDict",
    "GetPartnerStatusLinks",
    "GetPartnerStatusLinksTypedDict",
    "GetPartnerStatusRequest",
    "GetPartnerStatusRequestTypedDict",
    "GetPartnerStatusResponse",
    "GetPartnerStatusResponseTypedDict",
    "GetPaymentGlobals",
    "GetPaymentGlobalsTypedDict",
    "GetPaymentLinkGlobals",
    "GetPaymentLinkGlobalsTypedDict",
    "GetPaymentLinkPaymentsEmbedded",
    "GetPaymentLinkPaymentsEmbeddedTypedDict",
    "GetPaymentLinkPaymentsGlobals",
    "GetPaymentLinkPaymentsGlobalsTypedDict",
    "GetPaymentLinkPaymentsRequest",
    "GetPaymentLinkPaymentsRequestTypedDict",
    "GetPaymentLinkPaymentsResponse",
    "GetPaymentLinkPaymentsResponseBody",
    "GetPaymentLinkPaymentsResponseBodyTypedDict",
    "GetPaymentLinkPaymentsResponseTypedDict",
    "GetPaymentLinkRequest",
    "GetPaymentLinkRequestTypedDict",
    "GetPaymentRequest",
    "GetPaymentRequestTypedDict",
    "GetPermissionGlobals",
    "GetPermissionGlobalsTypedDict",
    "GetPermissionRequest",
    "GetPermissionRequestTypedDict",
    "GetPrimaryBalanceRequest",
    "GetPrimaryBalanceRequestTypedDict",
    "GetProfileGlobals",
    "GetProfileGlobalsTypedDict",
    "GetProfileRequest",
    "GetProfileRequestTypedDict",
    "GetRefundGlobals",
    "GetRefundGlobalsTypedDict",
    "GetRefundRequest",
    "GetRefundRequestTypedDict",
    "GetSalesInvoiceGlobals",
    "GetSalesInvoiceGlobalsTypedDict",
    "GetSalesInvoiceRequest",
    "GetSalesInvoiceRequestTypedDict",
    "GetSessionRequest",
    "GetSessionRequestTypedDict",
    "GetSettlementRequest",
    "GetSettlementRequestTypedDict",
    "GetSubscriptionGlobals",
    "GetSubscriptionGlobalsTypedDict",
    "GetSubscriptionRequest",
    "GetSubscriptionRequestTypedDict",
    "GetTerminalGlobals",
    "GetTerminalGlobalsTypedDict",
    "GetTerminalRequest",
    "GetTerminalRequestTypedDict",
    "GetWebhookEventGlobals",
    "GetWebhookEventGlobalsTypedDict",
    "GetWebhookEventRequest",
    "GetWebhookEventRequestTypedDict",
    "GetWebhookGlobals",
    "GetWebhookGlobalsTypedDict",
    "GetWebhookRequest",
    "GetWebhookRequestTypedDict",
    "InvoiceCompensation",
    "InvoiceCompensationTypedDict",
    "LineCategories",
    "LineCategoriesResponse",
    "ListAllChargebacksEmbedded",
    "ListAllChargebacksEmbeddedTypedDict",
    "ListAllChargebacksGlobals",
    "ListAllChargebacksGlobalsTypedDict",
    "ListAllChargebacksRequest",
    "ListAllChargebacksRequestTypedDict",
    "ListAllChargebacksResponse",
    "ListAllChargebacksResponseBody",
    "ListAllChargebacksResponseBodyTypedDict",
    "ListAllChargebacksResponseTypedDict",
    "ListAllMethodsEmbedded",
    "ListAllMethodsEmbeddedTypedDict",
    "ListAllMethodsGlobals",
    "ListAllMethodsGlobalsTypedDict",
    "ListAllMethodsLinks",
    "ListAllMethodsLinksTypedDict",
    "ListAllMethodsRequest",
    "ListAllMethodsRequestTypedDict",
    "ListAllMethodsResponse",
    "ListAllMethodsResponseTypedDict",
    "ListAllRefundsEmbedded",
    "ListAllRefundsEmbeddedTypedDict",
    "ListAllRefundsGlobals",
    "ListAllRefundsGlobalsTypedDict",
    "ListAllRefundsRequest",
    "ListAllRefundsRequestTypedDict",
    "ListAllRefundsResponse",
    "ListAllRefundsResponseBody",
    "ListAllRefundsResponseBodyTypedDict",
    "ListAllRefundsResponseTypedDict",
    "ListAllSubscriptionsEmbedded",
    "ListAllSubscriptionsEmbeddedTypedDict",
    "ListAllSubscriptionsGlobals",
    "ListAllSubscriptionsGlobalsTypedDict",
    "ListAllSubscriptionsRequest",
    "ListAllSubscriptionsRequestTypedDict",
    "ListAllSubscriptionsResponse",
    "ListAllSubscriptionsResponseBody",
    "ListAllSubscriptionsResponseBodyTypedDict",
    "ListAllSubscriptionsResponseTypedDict",
    "ListBalanceTransactionsEmbedded",
    "ListBalanceTransactionsEmbeddedTypedDict",
    "ListBalanceTransactionsGlobals",
    "ListBalanceTransactionsGlobalsTypedDict",
    "ListBalanceTransactionsRequest",
    "ListBalanceTransactionsRequestTypedDict",
    "ListBalanceTransactionsResponse",
    "ListBalanceTransactionsResponseBody",
    "ListBalanceTransactionsResponseBodyTypedDict",
    "ListBalanceTransactionsResponseTypedDict",
    "ListBalancesEmbedded",
    "ListBalancesEmbeddedTypedDict",
    "ListBalancesGlobals",
    "ListBalancesGlobalsTypedDict",
    "ListBalancesRequest",
    "ListBalancesRequestTypedDict",
    "ListBalancesResponse",
    "ListBalancesResponseBody",
    "ListBalancesResponseBodyTypedDict",
    "ListBalancesResponseTypedDict",
    "ListCapabilitiesEmbedded",
    "ListCapabilitiesEmbeddedTypedDict",
    "ListCapabilitiesLinks",
    "ListCapabilitiesLinksTypedDict",
    "ListCapabilitiesRequest",
    "ListCapabilitiesRequestTypedDict",
    "ListCapabilitiesResponse",
    "ListCapabilitiesResponseTypedDict",
    "ListCaptureResponse",
    "ListCaptureResponseLinks",
    "ListCaptureResponseLinksTypedDict",
    "ListCaptureResponseSettlementAmount",
    "ListCaptureResponseSettlementAmountTypedDict",
    "ListCaptureResponseStatus",
    "ListCaptureResponseTypedDict",
    "ListCapturesEmbedded",
    "ListCapturesEmbeddedTypedDict",
    "ListCapturesGlobals",
    "ListCapturesGlobalsTypedDict",
    "ListCapturesRequest",
    "ListCapturesRequestTypedDict",
    "ListCapturesResponse",
    "ListCapturesResponseBody",
    "ListCapturesResponseBodyTypedDict",
    "ListCapturesResponseTypedDict",
    "ListChargebacksEmbedded",
    "ListChargebacksEmbeddedTypedDict",
    "ListChargebacksGlobals",
    "ListChargebacksGlobalsTypedDict",
    "ListChargebacksRequest",
    "ListChargebacksRequestTypedDict",
    "ListChargebacksResponse",
    "ListChargebacksResponseBody",
    "ListChargebacksResponseBodyTypedDict",
    "ListChargebacksResponseTypedDict",
    "ListClientsClient",
    "ListClientsClientTypedDict",
    "ListClientsCommission",
    "ListClientsCommissionTypedDict",
    "ListClientsEmbedded",
    "ListClientsEmbeddedTypedDict",
    "ListClientsLinks",
    "ListClientsLinksTypedDict",
    "ListClientsRequest",
    "ListClientsRequestTypedDict",
    "ListClientsResponse",
    "ListClientsResponseBody",
    "ListClientsResponseBodyTypedDict",
    "ListClientsResponseTypedDict",
    "ListConnectBalanceTransfersEmbedded",
    "ListConnectBalanceTransfersEmbeddedTypedDict",
    "ListConnectBalanceTransfersGlobals",
    "ListConnectBalanceTransfersGlobalsTypedDict",
    "ListConnectBalanceTransfersRequest",
    "ListConnectBalanceTransfersRequestTypedDict",
    "ListConnectBalanceTransfersResponse",
    "ListConnectBalanceTransfersResponseBody",
    "ListConnectBalanceTransfersResponseBodyTypedDict",
    "ListConnectBalanceTransfersResponseTypedDict",
    "ListCustomerPaymentsEmbedded",
    "ListCustomerPaymentsEmbeddedTypedDict",
    "ListCustomerPaymentsGlobals",
    "ListCustomerPaymentsGlobalsTypedDict",
    "ListCustomerPaymentsRequest",
    "ListCustomerPaymentsRequestTypedDict",
    "ListCustomerPaymentsResponse",
    "ListCustomerPaymentsResponseBody",
    "ListCustomerPaymentsResponseBodyTypedDict",
    "ListCustomerPaymentsResponseTypedDict",
    "ListCustomerResponse",
    "ListCustomerResponseLinks",
    "ListCustomerResponseLinksTypedDict",
    "ListCustomerResponseTypedDict",
    "ListCustomersEmbedded",
    "ListCustomersEmbeddedTypedDict",
    "ListCustomersGlobals",
    "ListCustomersGlobalsTypedDict",
    "ListCustomersRequest",
    "ListCustomersRequestTypedDict",
    "ListCustomersResponse",
    "ListCustomersResponseBody",
    "ListCustomersResponseBodyTypedDict",
    "ListCustomersResponseTypedDict",
    "ListEntityBalance",
    "ListEntityBalanceAvailableAmount",
    "ListEntityBalanceAvailableAmountTypedDict",
    "ListEntityBalanceCurrency",
    "ListEntityBalanceLinks",
    "ListEntityBalanceLinksTypedDict",
    "ListEntityBalancePendingAmount",
    "ListEntityBalancePendingAmountTypedDict",
    "ListEntityBalanceStatus",
    "ListEntityBalanceTransferDestination",
    "ListEntityBalanceTransferDestinationTypedDict",
    "ListEntityBalanceTransferFrequency",
    "ListEntityBalanceTransferThreshold",
    "ListEntityBalanceTransferThresholdTypedDict",
    "ListEntityBalanceTypedDict",
    "ListEntityChargeback",
    "ListEntityChargebackLinks",
    "ListEntityChargebackLinksTypedDict",
    "ListEntityChargebackReason",
    "ListEntityChargebackReasonTypedDict",
    "ListEntityChargebackSettlementAmount",
    "ListEntityChargebackSettlementAmountTypedDict",
    "ListEntityChargebackTypedDict",
    "ListEntityInvoice",
    "ListEntityInvoiceGrossAmount",
    "ListEntityInvoiceGrossAmountTypedDict",
    "ListEntityInvoiceLine",
    "ListEntityInvoiceLineTypedDict",
    "ListEntityInvoiceLinks",
    "ListEntityInvoiceLinksTypedDict",
    "ListEntityInvoiceNetAmount",
    "ListEntityInvoiceNetAmountTypedDict",
    "ListEntityInvoiceStatus",
    "ListEntityInvoiceTypedDict",
    "ListEntityInvoiceVatAmount",
    "ListEntityInvoiceVatAmountTypedDict",
    "ListEntityMethod",
    "ListEntityMethodAll",
    "ListEntityMethodAllID",
    "ListEntityMethodAllImage",
    "ListEntityMethodAllImageTypedDict",
    "ListEntityMethodAllIssuer",
    "ListEntityMethodAllIssuerImage",
    "ListEntityMethodAllIssuerImageTypedDict",
    "ListEntityMethodAllIssuerTypedDict",
    "ListEntityMethodAllLinks",
    "ListEntityMethodAllLinksTypedDict",
    "ListEntityMethodAllMaximumAmount",
    "ListEntityMethodAllMaximumAmountTypedDict",
    "ListEntityMethodAllMinimumAmount",
    "ListEntityMethodAllMinimumAmountTypedDict",
    "ListEntityMethodAllTypedDict",
    "ListEntityMethodID",
    "ListEntityMethodImage",
    "ListEntityMethodImageTypedDict",
    "ListEntityMethodIssuer",
    "ListEntityMethodIssuerImage",
    "ListEntityMethodIssuerImageTypedDict",
    "ListEntityMethodIssuerTypedDict",
    "ListEntityMethodLinks",
    "ListEntityMethodLinksTypedDict",
    "ListEntityMethodMaximumAmount",
    "ListEntityMethodMaximumAmountTypedDict",
    "ListEntityMethodMinimumAmount",
    "ListEntityMethodMinimumAmountTypedDict",
    "ListEntityMethodTypedDict",
    "ListEntityPermission",
    "ListEntityPermissionLinks",
    "ListEntityPermissionLinksTypedDict",
    "ListEntityPermissionTypedDict",
    "ListEntityRefund",
    "ListEntityRefundExternalReference",
    "ListEntityRefundExternalReferenceTypedDict",
    "ListEntityRefundLinks",
    "ListEntityRefundLinksTypedDict",
    "ListEntityRefundRoutingReversal",
    "ListEntityRefundRoutingReversalTypedDict",
    "ListEntityRefundSettlementAmount",
    "ListEntityRefundSettlementAmountTypedDict",
    "ListEntityRefundSource",
    "ListEntityRefundSourceTypedDict",
    "ListEntityRefundStatus",
    "ListEntityRefundTypedDict",
    "ListEntitySettlement",
    "ListEntitySettlementAmount",
    "ListEntitySettlementAmountTypedDict",
    "ListEntitySettlementCost",
    "ListEntitySettlementCostTypedDict",
    "ListEntitySettlementLinks",
    "ListEntitySettlementLinksTypedDict",
    "ListEntitySettlementPeriods",
    "ListEntitySettlementPeriodsTypedDict",
    "ListEntitySettlementRate",
    "ListEntitySettlementRateTypedDict",
    "ListEntitySettlementRevenue",
    "ListEntitySettlementRevenueTypedDict",
    "ListEntitySettlementStatus",
    "ListEntitySettlementTypedDict",
    "ListEntityTerminal",
    "ListEntityTerminalLinks",
    "ListEntityTerminalLinksTypedDict",
    "ListEntityTerminalStatus",
    "ListEntityTerminalTypedDict",
    "ListEntityWebhook",
    "ListEntityWebhookLinks",
    "ListEntityWebhookLinksTypedDict",
    "ListEntityWebhookTypedDict",
    "ListInvoicesEmbedded",
    "ListInvoicesEmbeddedTypedDict",
    "ListInvoicesRequest",
    "ListInvoicesRequestTypedDict",
    "ListInvoicesResponse",
    "ListInvoicesResponseBody",
    "ListInvoicesResponseBodyTypedDict",
    "ListInvoicesResponseTypedDict",
    "ListLinks",
    "ListLinksTypedDict",
    "ListMandateResponse",
    "ListMandateResponseDetails",
    "ListMandateResponseDetailsTypedDict",
    "ListMandateResponseLinks",
    "ListMandateResponseLinksTypedDict",
    "ListMandateResponseStatus",
    "ListMandateResponseTypedDict",
    "ListMandatesEmbedded",
    "ListMandatesEmbeddedTypedDict",
    "ListMandatesGlobals",
    "ListMandatesGlobalsTypedDict",
    "ListMandatesRequest",
    "ListMandatesRequestTypedDict",
    "ListMandatesResponse",
    "ListMandatesResponseBody",
    "ListMandatesResponseBodyTypedDict",
    "ListMandatesResponseTypedDict",
    "ListMethodsEmbedded",
    "ListMethodsEmbeddedTypedDict",
    "ListMethodsGlobals",
    "ListMethodsGlobalsTypedDict",
    "ListMethodsLinks",
    "ListMethodsLinksTypedDict",
    "ListMethodsRequest",
    "ListMethodsRequestTypedDict",
    "ListMethodsResponse",
    "ListMethodsResponseTypedDict",
    "ListPaymentLinksEmbedded",
    "ListPaymentLinksEmbeddedTypedDict",
    "ListPaymentLinksGlobals",
    "ListPaymentLinksGlobalsTypedDict",
    "ListPaymentLinksRequest",
    "ListPaymentLinksRequestTypedDict",
    "ListPaymentLinksResponse",
    "ListPaymentLinksResponseBody",
    "ListPaymentLinksResponseBodyTypedDict",
    "ListPaymentLinksResponseTypedDict",
    "ListPaymentResponse",
    "ListPaymentResponseAmountCaptured",
    "ListPaymentResponseAmountCapturedTypedDict",
    "ListPaymentResponseAmountChargedBack",
    "ListPaymentResponseAmountChargedBackTypedDict",
    "ListPaymentResponseAmountRefunded",
    "ListPaymentResponseAmountRefundedTypedDict",
    "ListPaymentResponseAmountRemaining",
    "ListPaymentResponseAmountRemainingTypedDict",
    "ListPaymentResponseApplicationFee",
    "ListPaymentResponseApplicationFeeTypedDict",
    "ListPaymentResponseBillingAddress",
    "ListPaymentResponseBillingAddressTypedDict",
    "ListPaymentResponseDetails",
    "ListPaymentResponseDetailsTypedDict",
    "ListPaymentResponseLine",
    "ListPaymentResponseLineTypedDict",
    "ListPaymentResponseLinks",
    "ListPaymentResponseLinksTypedDict",
    "ListPaymentResponseQrCode",
    "ListPaymentResponseQrCodeTypedDict",
    "ListPaymentResponseReceipt",
    "ListPaymentResponseReceiptTypedDict",
    "ListPaymentResponseSettlementAmount",
    "ListPaymentResponseSettlementAmountTypedDict",
    "ListPaymentResponseStatus",
    "ListPaymentResponseTypedDict",
    "ListPaymentsEmbedded",
    "ListPaymentsEmbeddedTypedDict",
    "ListPaymentsGlobals",
    "ListPaymentsGlobalsTypedDict",
    "ListPaymentsRequest",
    "ListPaymentsRequestTypedDict",
    "ListPaymentsResponse",
    "ListPaymentsResponseBody",
    "ListPaymentsResponseBodyTypedDict",
    "ListPaymentsResponseTypedDict",
    "ListPermissionsEmbedded",
    "ListPermissionsEmbeddedTypedDict",
    "ListPermissionsLinks",
    "ListPermissionsLinksTypedDict",
    "ListPermissionsRequest",
    "ListPermissionsRequestTypedDict",
    "ListPermissionsResponse",
    "ListPermissionsResponseTypedDict",
    "ListProfileResponse",
    "ListProfileResponseLinks",
    "ListProfileResponseLinksTypedDict",
    "ListProfileResponseReview",
    "ListProfileResponseReviewTypedDict",
    "ListProfileResponseStatus",
    "ListProfileResponseTypedDict",
    "ListProfilesEmbedded",
    "ListProfilesEmbeddedTypedDict",
    "ListProfilesRequest",
    "ListProfilesRequestTypedDict",
    "ListProfilesResponse",
    "ListProfilesResponseBody",
    "ListProfilesResponseBodyTypedDict",
    "ListProfilesResponseTypedDict",
    "ListRefundsEmbedded",
    "ListRefundsEmbeddedTypedDict",
    "ListRefundsGlobals",
    "ListRefundsGlobalsTypedDict",
    "ListRefundsRequest",
    "ListRefundsRequestTypedDict",
    "ListRefundsResponse",
    "ListRefundsResponseBody",
    "ListRefundsResponseBodyTypedDict",
    "ListRefundsResponseTypedDict",
    "ListRouteGetResponse",
    "ListRouteGetResponseDestination",
    "ListRouteGetResponseDestinationTypedDict",
    "ListRouteGetResponseLinks",
    "ListRouteGetResponseLinksTypedDict",
    "ListRouteGetResponseTypedDict",
    "ListSalesInvoiceResponse",
    "ListSalesInvoiceResponseAmountDue",
    "ListSalesInvoiceResponseAmountDueTypedDict",
    "ListSalesInvoiceResponseDiscountedSubtotalAmount",
    "ListSalesInvoiceResponseDiscountedSubtotalAmountTypedDict",
    "ListSalesInvoiceResponseLinks",
    "ListSalesInvoiceResponseLinksTypedDict",
    "ListSalesInvoiceResponseMetadata",
    "ListSalesInvoiceResponseMetadataTypedDict",
    "ListSalesInvoiceResponseSubtotalAmount",
    "ListSalesInvoiceResponseSubtotalAmountTypedDict",
    "ListSalesInvoiceResponseTotalAmount",
    "ListSalesInvoiceResponseTotalAmountTypedDict",
    "ListSalesInvoiceResponseTotalVatAmount",
    "ListSalesInvoiceResponseTotalVatAmountTypedDict",
    "ListSalesInvoiceResponseTypedDict",
    "ListSalesInvoicesEmbedded",
    "ListSalesInvoicesEmbeddedTypedDict",
    "ListSalesInvoicesGlobals",
    "ListSalesInvoicesGlobalsTypedDict",
    "ListSalesInvoicesRequest",
    "ListSalesInvoicesRequestTypedDict",
    "ListSalesInvoicesResponse",
    "ListSalesInvoicesResponseBody",
    "ListSalesInvoicesResponseBodyTypedDict",
    "ListSalesInvoicesResponseTypedDict",
    "ListSettlementCapturesEmbedded",
    "ListSettlementCapturesEmbeddedTypedDict",
    "ListSettlementCapturesGlobals",
    "ListSettlementCapturesGlobalsTypedDict",
    "ListSettlementCapturesRequest",
    "ListSettlementCapturesRequestTypedDict",
    "ListSettlementCapturesResponse",
    "ListSettlementCapturesResponseBody",
    "ListSettlementCapturesResponseBodyTypedDict",
    "ListSettlementCapturesResponseTypedDict",
    "ListSettlementChargebacksEmbedded",
    "ListSettlementChargebacksEmbeddedTypedDict",
    "ListSettlementChargebacksGlobals",
    "ListSettlementChargebacksGlobalsTypedDict",
    "ListSettlementChargebacksRequest",
    "ListSettlementChargebacksRequestTypedDict",
    "ListSettlementChargebacksResponse",
    "ListSettlementChargebacksResponseBody",
    "ListSettlementChargebacksResponseBodyTypedDict",
    "ListSettlementChargebacksResponseTypedDict",
    "ListSettlementPaymentsEmbedded",
    "ListSettlementPaymentsEmbeddedTypedDict",
    "ListSettlementPaymentsGlobals",
    "ListSettlementPaymentsGlobalsTypedDict",
    "ListSettlementPaymentsRequest",
    "ListSettlementPaymentsRequestTypedDict",
    "ListSettlementPaymentsResponse",
    "ListSettlementPaymentsResponseBody",
    "ListSettlementPaymentsResponseBodyTypedDict",
    "ListSettlementPaymentsResponseTypedDict",
    "ListSettlementRefundsEmbedded",
    "ListSettlementRefundsEmbeddedTypedDict",
    "ListSettlementRefundsGlobals",
    "ListSettlementRefundsGlobalsTypedDict",
    "ListSettlementRefundsRequest",
    "ListSettlementRefundsRequestTypedDict",
    "ListSettlementRefundsResponse",
    "ListSettlementRefundsResponseBody",
    "ListSettlementRefundsResponseBodyTypedDict",
    "ListSettlementRefundsResponseTypedDict",
    "ListSettlementsEmbedded",
    "ListSettlementsEmbeddedTypedDict",
    "ListSettlementsRequest",
    "ListSettlementsRequestTypedDict",
    "ListSettlementsResponse",
    "ListSettlementsResponseBody",
    "ListSettlementsResponseBodyTypedDict",
    "ListSettlementsResponseTypedDict",
    "ListSubscriptionPaymentsEmbedded",
    "ListSubscriptionPaymentsEmbeddedTypedDict",
    "ListSubscriptionPaymentsGlobals",
    "ListSubscriptionPaymentsGlobalsTypedDict",
    "ListSubscriptionPaymentsRequest",
    "ListSubscriptionPaymentsRequestTypedDict",
    "ListSubscriptionPaymentsResponse",
    "ListSubscriptionPaymentsResponseBody",
    "ListSubscriptionPaymentsResponseBodyTypedDict",
    "ListSubscriptionPaymentsResponseTypedDict",
    "ListSubscriptionResponse",
    "ListSubscriptionResponseApplicationFee",
    "ListSubscriptionResponseApplicationFeeTypedDict",
    "ListSubscriptionResponseLinks",
    "ListSubscriptionResponseLinksTypedDict",
    "ListSubscriptionResponseStatus",
    "ListSubscriptionResponseTypedDict",
    "ListSubscriptionsEmbedded",
    "ListSubscriptionsEmbeddedTypedDict",
    "ListSubscriptionsGlobals",
    "ListSubscriptionsGlobalsTypedDict",
    "ListSubscriptionsRequest",
    "ListSubscriptionsRequestTypedDict",
    "ListSubscriptionsResponse",
    "ListSubscriptionsResponseBody",
    "ListSubscriptionsResponseBodyTypedDict",
    "ListSubscriptionsResponseTypedDict",
    "ListTerminalsEmbedded",
    "ListTerminalsEmbeddedTypedDict",
    "ListTerminalsGlobals",
    "ListTerminalsGlobalsTypedDict",
    "ListTerminalsRequest",
    "ListTerminalsRequestTypedDict",
    "ListTerminalsResponse",
    "ListTerminalsResponseBody",
    "ListTerminalsResponseBodyTypedDict",
    "ListTerminalsResponseTypedDict",
    "ListWebhooksEmbedded",
    "ListWebhooksEmbeddedTypedDict",
    "ListWebhooksGlobals",
    "ListWebhooksGlobalsTypedDict",
    "ListWebhooksRequest",
    "ListWebhooksRequestTypedDict",
    "ListWebhooksResponse",
    "ListWebhooksResponseBody",
    "ListWebhooksResponseBodyTypedDict",
    "ListWebhooksResponseTypedDict",
    "Locale",
    "LocaleResponse",
    "ManagedFee",
    "ManagedFeeTypedDict",
    "MandateDetailsCardLabelResponse",
    "MandateMethod",
    "MandateMethodResponse",
    "MandateRequest",
    "MandateRequestTypedDict",
    "MandateResponse",
    "MandateResponseDetails",
    "MandateResponseDetailsTypedDict",
    "MandateResponseLinks",
    "MandateResponseLinksTypedDict",
    "MandateResponseStatus",
    "MandateResponseTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "Method",
    "MethodEnum",
    "MethodIncludeWalletsParameter",
    "MethodResourceParameter",
    "MethodResponse",
    "MethodStatus",
    "MethodTypedDict",
    "Mode",
    "NoResponseError",
    "OnboardingVatRegulation",
    "Open",
    "OpenTypedDict",
    "Organization",
    "OrganizationTypedDict",
    "OrganizationVatRegulation",
    "OutgoingTransfer",
    "OutgoingTransferTypedDict",
    "Owner",
    "OwnerTypedDict",
    "PartnerType",
    "PaymentAddress",
    "PaymentAddressTypedDict",
    "PaymentCommission",
    "PaymentCommissionTypedDict",
    "PaymentCreateRouteRequest",
    "PaymentCreateRouteRequestTypedDict",
    "PaymentDetailsCardAuditionResponse",
    "PaymentDetailsCardFundingResponse",
    "PaymentDetailsCardLabelResponse",
    "PaymentDetailsCardSecurityResponse",
    "PaymentDetailsFailureReasonResponse",
    "PaymentDetailsFeeRegionResponse",
    "PaymentDetailsReceiptCardReadMethodResponse",
    "PaymentDetailsReceiptCardVerificationMethodResponse",
    "PaymentDetailsSellerProtectionResponse",
    "PaymentDetailsWalletResponse",
    "PaymentFee",
    "PaymentFeeTypedDict",
    "PaymentGetRouteRequest",
    "PaymentGetRouteRequestTypedDict",
    "PaymentLineItem",
    "PaymentLineItemResponse",
    "PaymentLineItemResponseTypedDict",
    "PaymentLineItemTypedDict",
    "PaymentLineType",
    "PaymentLineTypeResponse",
    "PaymentLinkMethod",
    "PaymentLinkMethodResponse",
    "PaymentLinkResponse",
    "PaymentLinkResponseApplicationFee",
    "PaymentLinkResponseApplicationFeeTypedDict",
    "PaymentLinkResponseLinks",
    "PaymentLinkResponseLinksTypedDict",
    "PaymentLinkResponseTypedDict",
    "PaymentLinkSequenceType",
    "PaymentLinkSequenceTypeResponse",
    "PaymentListRoutesEmbedded",
    "PaymentListRoutesEmbeddedTypedDict",
    "PaymentListRoutesGlobals",
    "PaymentListRoutesGlobalsTypedDict",
    "PaymentListRoutesLinks",
    "PaymentListRoutesLinksTypedDict",
    "PaymentListRoutesRequest",
    "PaymentListRoutesRequestTypedDict",
    "PaymentListRoutesResponse",
    "PaymentListRoutesResponseTypedDict",
    "PaymentMethod",
    "PaymentRequest",
    "PaymentRequestApplicationFee",
    "PaymentRequestApplicationFeeTypedDict",
    "PaymentRequestBillingAddress",
    "PaymentRequestBillingAddressTypedDict",
    "PaymentRequestLine",
    "PaymentRequestLineTypedDict",
    "PaymentRequestTypedDict",
    "PaymentResponse",
    "PaymentResponseAmountCaptured",
    "PaymentResponseAmountCapturedTypedDict",
    "PaymentResponseAmountChargedBack",
    "PaymentResponseAmountChargedBackTypedDict",
    "PaymentResponseAmountRefunded",
    "PaymentResponseAmountRefundedTypedDict",
    "PaymentResponseAmountRemaining",
    "PaymentResponseAmountRemainingTypedDict",
    "PaymentResponseApplicationFee",
    "PaymentResponseApplicationFeeTypedDict",
    "PaymentResponseBillingAddress",
    "PaymentResponseBillingAddressTypedDict",
    "PaymentResponseDetails",
    "PaymentResponseDetailsTypedDict",
    "PaymentResponseLine",
    "PaymentResponseLineTypedDict",
    "PaymentResponseLinks",
    "PaymentResponseLinksTypedDict",
    "PaymentResponseQrCode",
    "PaymentResponseQrCodeTypedDict",
    "PaymentResponseReceipt",
    "PaymentResponseReceiptTypedDict",
    "PaymentResponseSettlementAmount",
    "PaymentResponseSettlementAmountTypedDict",
    "PaymentResponseStatus",
    "PaymentResponseTypedDict",
    "Payments",
    "PaymentsTypedDict",
    "PendingBalance",
    "PendingBalanceTypedDict",
    "PlatformPaymentChargeback",
    "PlatformPaymentChargebackTypedDict",
    "PlatformPaymentRefund",
    "PlatformPaymentRefundTypedDict",
    "PostPaymentSplitPayment",
    "PostPaymentSplitPaymentTypedDict",
    "Pricing",
    "PricingTypedDict",
    "Profile",
    "ProfileRequest",
    "ProfileRequestTypedDict",
    "ProfileResponse",
    "ProfileResponseLinks",
    "ProfileResponseLinksTypedDict",
    "ProfileResponseReview",
    "ProfileResponseReviewTypedDict",
    "ProfileResponseStatus",
    "ProfileResponseTypedDict",
    "ProfileReviewStatusResponse",
    "ProfileTypedDict",
    "RecurringLineItem",
    "RecurringLineItemTypedDict",
    "Refund",
    "RefundCompensation",
    "RefundCompensationTypedDict",
    "RefundExternalReferenceType",
    "RefundExternalReferenceTypeResponse",
    "RefundRequest",
    "RefundRequestExternalReference",
    "RefundRequestExternalReferenceTypedDict",
    "RefundRequestRoutingReversal",
    "RefundRequestRoutingReversalTypedDict",
    "RefundRequestSource",
    "RefundRequestSourceTypedDict",
    "RefundRequestTypedDict",
    "RefundTypedDict",
    "Refunds",
    "RefundsTypedDict",
    "ReimbursementFee",
    "ReimbursementFeeTypedDict",
    "ReleaseAuthorizationRequest",
    "ReleaseAuthorizationRequestBody",
    "ReleaseAuthorizationRequestBodyTypedDict",
    "ReleaseAuthorizationRequestTypedDict",
    "RequestApplePayPaymentSessionRequest",
    "RequestApplePayPaymentSessionRequestBody",
    "RequestApplePayPaymentSessionRequestBodyTypedDict",
    "RequestApplePayPaymentSessionRequestTypedDict",
    "ResponseValidationError",
    "ReturnedManagedFee",
    "ReturnedManagedFeeTypedDict",
    "ReturnedPlatformPaymentRefund",
    "ReturnedPlatformPaymentRefundTypedDict",
    "ReturnedRefund",
    "ReturnedRefundCompensation",
    "ReturnedRefundCompensationTypedDict",
    "ReturnedRefundTypedDict",
    "ReturnedTransfer",
    "ReturnedTransferTypedDict",
    "ReversedChargebackCompensation",
    "ReversedChargebackCompensationTypedDict",
    "ReversedPlatformPaymentChargeback",
    "ReversedPlatformPaymentChargebackTypedDict",
    "RevokeMandateRequest",
    "RevokeMandateRequestBody",
    "RevokeMandateRequestBodyTypedDict",
    "RevokeMandateRequestTypedDict",
    "RouteCreateRequest",
    "RouteCreateRequestDestination",
    "RouteCreateRequestDestinationTypedDict",
    "RouteCreateRequestTypedDict",
    "RouteCreateResponse",
    "RouteCreateResponseDestination",
    "RouteCreateResponseDestinationTypedDict",
    "RouteCreateResponseLinks",
    "RouteCreateResponseLinksTypedDict",
    "RouteCreateResponseTypedDict",
    "RouteDestinationType",
    "RouteDestinationTypeResponse",
    "RouteGetResponse",
    "RouteGetResponseDestination",
    "RouteGetResponseDestinationTypedDict",
    "RouteGetResponseLinks",
    "RouteGetResponseLinksTypedDict",
    "RouteGetResponseTypedDict",
    "SalesInvoiceDiscount",
    "SalesInvoiceDiscountResponse",
    "SalesInvoiceDiscountResponseTypedDict",
    "SalesInvoiceDiscountType",
    "SalesInvoiceDiscountTypeResponse",
    "SalesInvoiceDiscountTypedDict",
    "SalesInvoiceEmailDetails",
    "SalesInvoiceEmailDetailsTypedDict",
    "SalesInvoiceLineItem",
    "SalesInvoiceLineItemResponse",
    "SalesInvoiceLineItemResponseTypedDict",
    "SalesInvoiceLineItemTypedDict",
    "SalesInvoicePaymentDetails",
    "SalesInvoicePaymentDetailsResponse",
    "SalesInvoicePaymentDetailsResponseTypedDict",
    "SalesInvoicePaymentDetailsSource",
    "SalesInvoicePaymentDetailsSourceResponse",
    "SalesInvoicePaymentDetailsTypedDict",
    "SalesInvoicePaymentTerm",
    "SalesInvoicePaymentTermResponse",
    "SalesInvoiceRecipient",
    "SalesInvoiceRecipientLocale",
    "SalesInvoiceRecipientLocaleResponse",
    "SalesInvoiceRecipientResponse",
    "SalesInvoiceRecipientResponseTypedDict",
    "SalesInvoiceRecipientType",
    "SalesInvoiceRecipientTypeResponse",
    "SalesInvoiceRecipientTypedDict",
    "SalesInvoiceRequest",
    "SalesInvoiceRequestMetadata",
    "SalesInvoiceRequestMetadataTypedDict",
    "SalesInvoiceRequestTypedDict",
    "SalesInvoiceResponse",
    "SalesInvoiceResponseAmountDue",
    "SalesInvoiceResponseAmountDueTypedDict",
    "SalesInvoiceResponseDiscountedSubtotalAmount",
    "SalesInvoiceResponseDiscountedSubtotalAmountTypedDict",
    "SalesInvoiceResponseLinks",
    "SalesInvoiceResponseLinksTypedDict",
    "SalesInvoiceResponseMetadata",
    "SalesInvoiceResponseMetadataTypedDict",
    "SalesInvoiceResponseSubtotalAmount",
    "SalesInvoiceResponseSubtotalAmountTypedDict",
    "SalesInvoiceResponseTotalAmount",
    "SalesInvoiceResponseTotalAmountTypedDict",
    "SalesInvoiceResponseTotalVatAmount",
    "SalesInvoiceResponseTotalVatAmountTypedDict",
    "SalesInvoiceResponseTypedDict",
    "SalesInvoiceStatus",
    "SalesInvoiceStatusResponse",
    "SalesInvoiceVatMode",
    "SalesInvoiceVatModeResponse",
    "SalesInvoiceVatScheme",
    "SalesInvoiceVatSchemeResponse",
    "Security",
    "SecurityTypedDict",
    "SequenceType",
    "SequenceTypeResponse",
    "SessionLineItem",
    "SessionLineItemResponse",
    "SessionLineItemResponseTypedDict",
    "SessionLineItemTypedDict",
    "SessionRequest",
    "SessionRequestPayment",
    "SessionRequestPaymentTypedDict",
    "SessionRequestTypedDict",
    "SessionResponse",
    "SessionResponseLinks",
    "SessionResponseLinksTypedDict",
    "SessionResponsePayment",
    "SessionResponsePaymentTypedDict",
    "SessionResponseStatus",
    "SessionResponseTypedDict",
    "SessionSequenceType",
    "SessionSequenceTypeResponse",
    "Sorting",
    "SplitPayment",
    "SplitPaymentTypedDict",
    "StatusReason",
    "StatusReasonTypedDict",
    "SubGroup",
    "SubGroupTypedDict",
    "SubTotals",
    "SubTotalsTypedDict",
    "SubmitOnboardingDataRequest",
    "SubmitOnboardingDataRequestBody",
    "SubmitOnboardingDataRequestBodyTypedDict",
    "SubmitOnboardingDataRequestTypedDict",
    "SubscriptionMethod",
    "SubscriptionMethodResponse",
    "SubscriptionRequest",
    "SubscriptionRequestApplicationFee",
    "SubscriptionRequestApplicationFeeTypedDict",
    "SubscriptionRequestTypedDict",
    "SubscriptionResponse",
    "SubscriptionResponseApplicationFee",
    "SubscriptionResponseApplicationFeeTypedDict",
    "SubscriptionResponseLinks",
    "SubscriptionResponseLinksTypedDict",
    "SubscriptionResponseStatus",
    "SubscriptionResponseTypedDict",
    "TerminalBrand",
    "TerminalModel",
    "TestWebhookRequest",
    "TestWebhookRequestBody",
    "TestWebhookRequestBodyTypedDict",
    "TestWebhookRequestTypedDict",
    "Topups",
    "TopupsTypedDict",
    "Totals",
    "TotalsTypedDict",
    "Transfers",
    "TransfersTypedDict",
    "Type",
    "URL",
    "URLNullable",
    "URLNullableTypedDict",
    "URLTypedDict",
    "UnauthorizedDirectDebit",
    "UnauthorizedDirectDebitTypedDict",
    "UpdateCustomerRequest",
    "UpdateCustomerRequestBody",
    "UpdateCustomerRequestBodyTypedDict",
    "UpdateCustomerRequestTypedDict",
    "UpdatePaymentLinkRequest",
    "UpdatePaymentLinkRequestBody",
    "UpdatePaymentLinkRequestBodyTypedDict",
    "UpdatePaymentLinkRequestTypedDict",
    "UpdatePaymentRequest",
    "UpdatePaymentRequestBody",
    "UpdatePaymentRequestBodyTypedDict",
    "UpdatePaymentRequestTypedDict",
    "UpdateProfileRequest",
    "UpdateProfileRequestBody",
    "UpdateProfileRequestBodyTypedDict",
    "UpdateProfileRequestTypedDict",
    "UpdateSalesInvoiceRequest",
    "UpdateSalesInvoiceRequestBody",
    "UpdateSalesInvoiceRequestBodyTypedDict",
    "UpdateSalesInvoiceRequestTypedDict",
    "UpdateSubscriptionRequest",
    "UpdateSubscriptionRequestBody",
    "UpdateSubscriptionRequestBodyTypedDict",
    "UpdateSubscriptionRequestTypedDict",
    "UpdateWebhookEventTypes",
    "UpdateWebhookEventTypesTypedDict",
    "UpdateWebhookRequest",
    "UpdateWebhookRequestBody",
    "UpdateWebhookRequestBodyTypedDict",
    "UpdateWebhookRequestTypedDict",
    "UserAgentToken",
    "UserAgentTokenTypedDict",
    "WebhookEventTypes",
    "WebhookStatus",
]

_dynamic_imports: dict[str, str] = {
    "Address": ".address",
    "AddressTypedDict": ".address",
    "Amount": ".amount",
    "AmountTypedDict": ".amount",
    "AmountNullable": ".amount_nullable",
    "AmountNullableTypedDict": ".amount_nullable",
    "APIError": ".apierror",
    "BalanceCardAudience": ".balance_card_audience",
    "BalanceCardIssuer": ".balance_card_issuer",
    "BalanceCardRegion": ".balance_card_region",
    "BalanceFeeType": ".balance_fee_type",
    "BalancePrepaymentPartType": ".balance_prepayment_part_type",
    "BalanceReportGrouping": ".balance_report_grouping",
    "BalanceTransactionType": ".balance_transaction_type",
    "BalanceTransferCategory": ".balance_transfer_category",
    "BalanceTransferCategoryResponse": ".balance_transfer_category_response",
    "BalanceTransferDestinationType": ".balance_transfer_destination_type",
    "BalanceTransferPartyType": ".balance_transfer_party_type",
    "BalanceTransferPartyTypeResponse": ".balance_transfer_party_type_response",
    "BalanceTransferStatus": ".balance_transfer_status",
    "BalanceTransferStatusReasonResponse": ".balance_transfer_status_reason_response",
    "BillingAddress": ".billingaddress",
    "BillingAddressTypedDict": ".billingaddress",
    "CancelPaymentRequest": ".cancel_paymentop",
    "CancelPaymentRequestBody": ".cancel_paymentop",
    "CancelPaymentRequestBodyTypedDict": ".cancel_paymentop",
    "CancelPaymentRequestTypedDict": ".cancel_paymentop",
    "CancelRefundGlobals": ".cancel_refundop",
    "CancelRefundGlobalsTypedDict": ".cancel_refundop",
    "CancelRefundRequest": ".cancel_refundop",
    "CancelRefundRequestTypedDict": ".cancel_refundop",
    "CancelSubscriptionRequest": ".cancel_subscriptionop",
    "CancelSubscriptionRequestBody": ".cancel_subscriptionop",
    "CancelSubscriptionRequestBodyTypedDict": ".cancel_subscriptionop",
    "CancelSubscriptionRequestTypedDict": ".cancel_subscriptionop",
    "CapabilityRequirementStatus": ".capability_requirement_status",
    "CapabilityStatus": ".capability_status",
    "CapabilityStatusReason": ".capability_status_reason",
    "CaptureMode": ".capture_mode",
    "CaptureModeResponse": ".capture_mode_response",
    "CaptureResponse": ".capture_response",
    "CaptureResponseLinks": ".capture_response",
    "CaptureResponseLinksTypedDict": ".capture_response",
    "CaptureResponseSettlementAmount": ".capture_response",
    "CaptureResponseSettlementAmountTypedDict": ".capture_response",
    "CaptureResponseStatus": ".capture_response",
    "CaptureResponseTypedDict": ".capture_response",
    "ClientLinkRequest": ".client_link_request",
    "ClientLinkRequestAddress": ".client_link_request",
    "ClientLinkRequestAddressTypedDict": ".client_link_request",
    "ClientLinkRequestTypedDict": ".client_link_request",
    "Owner": ".client_link_request",
    "OwnerTypedDict": ".client_link_request",
    "ClientLinkResponse": ".client_link_response",
    "ClientLinkResponseLinks": ".client_link_response",
    "ClientLinkResponseLinksTypedDict": ".client_link_response",
    "ClientLinkResponseTypedDict": ".client_link_response",
    "ComponentsSubTotals": ".components_sub_totals",
    "ComponentsSubTotalsTypedDict": ".components_sub_totals",
    "CreateCaptureRequest": ".create_captureop",
    "CreateCaptureRequestTypedDict": ".create_captureop",
    "CreateClientLinkRequest": ".create_client_linkop",
    "CreateClientLinkRequestTypedDict": ".create_client_linkop",
    "CreateConnectBalanceTransferRequest": ".create_connect_balance_transferop",
    "CreateConnectBalanceTransferRequestTypedDict": ".create_connect_balance_transferop",
    "CreateCustomerPaymentRequest": ".create_customer_paymentop",
    "CreateCustomerPaymentRequestTypedDict": ".create_customer_paymentop",
    "CreateCustomerRequest": ".create_customerop",
    "CreateCustomerRequestTypedDict": ".create_customerop",
    "CreateMandateRequest": ".create_mandateop",
    "CreateMandateRequestTypedDict": ".create_mandateop",
    "CreatePaymentLinkApplicationFee": ".create_payment_linkop",
    "CreatePaymentLinkApplicationFeeTypedDict": ".create_payment_linkop",
    "CreatePaymentLinkRequest": ".create_payment_linkop",
    "CreatePaymentLinkRequestBody": ".create_payment_linkop",
    "CreatePaymentLinkRequestBodyTypedDict": ".create_payment_linkop",
    "CreatePaymentLinkRequestTypedDict": ".create_payment_linkop",
    "CreatePaymentRequest": ".create_paymentop",
    "CreatePaymentRequestTypedDict": ".create_paymentop",
    "CreateProfileRequest": ".create_profileop",
    "CreateProfileRequestTypedDict": ".create_profileop",
    "CreateRefundRequest": ".create_refundop",
    "CreateRefundRequestTypedDict": ".create_refundop",
    "CreateSalesInvoiceRequest": ".create_sales_invoiceop",
    "CreateSalesInvoiceRequestTypedDict": ".create_sales_invoiceop",
    "CreateSessionRequest": ".create_sessionop",
    "CreateSessionRequestTypedDict": ".create_sessionop",
    "CreateSubscriptionRequest": ".create_subscriptionop",
    "CreateSubscriptionRequestTypedDict": ".create_subscriptionop",
    "CreateWebhook": ".create_webhook",
    "CreateWebhookLinks": ".create_webhook",
    "CreateWebhookLinksTypedDict": ".create_webhook",
    "CreateWebhookTypedDict": ".create_webhook",
    "CreateWebhookEventTypes": ".create_webhookop",
    "CreateWebhookEventTypesTypedDict": ".create_webhookop",
    "CreateWebhookRequest": ".create_webhookop",
    "CreateWebhookRequestBody": ".create_webhookop",
    "CreateWebhookRequestBodyTypedDict": ".create_webhookop",
    "CreateWebhookRequestTypedDict": ".create_webhookop",
    "Currencies": ".currencies",
    "CustomerResponse": ".customer_response",
    "CustomerResponseLinks": ".customer_response",
    "CustomerResponseLinksTypedDict": ".customer_response",
    "CustomerResponseTypedDict": ".customer_response",
    "DeleteCustomerRequest": ".delete_customerop",
    "DeleteCustomerRequestBody": ".delete_customerop",
    "DeleteCustomerRequestBodyTypedDict": ".delete_customerop",
    "DeleteCustomerRequestTypedDict": ".delete_customerop",
    "DeletePaymentLinkRequest": ".delete_payment_linkop",
    "DeletePaymentLinkRequestBody": ".delete_payment_linkop",
    "DeletePaymentLinkRequestBodyTypedDict": ".delete_payment_linkop",
    "DeletePaymentLinkRequestTypedDict": ".delete_payment_linkop",
    "DeleteProfileRequest": ".delete_profileop",
    "DeleteProfileRequestTypedDict": ".delete_profileop",
    "DeleteSalesInvoiceRequest": ".delete_sales_invoiceop",
    "DeleteSalesInvoiceRequestTypedDict": ".delete_sales_invoiceop",
    "DeleteValuesSalesInvoice": ".delete_values_sales_invoice",
    "DeleteValuesSalesInvoiceTypedDict": ".delete_values_sales_invoice",
    "DeleteWebhookRequest": ".delete_webhookop",
    "DeleteWebhookRequestBody": ".delete_webhookop",
    "DeleteWebhookRequestBodyTypedDict": ".delete_webhookop",
    "DeleteWebhookRequestTypedDict": ".delete_webhookop",
    "EntityBalance": ".entity_balance",
    "EntityBalanceAvailableAmount": ".entity_balance",
    "EntityBalanceAvailableAmountTypedDict": ".entity_balance",
    "EntityBalanceCurrency": ".entity_balance",
    "EntityBalanceLinks": ".entity_balance",
    "EntityBalanceLinksTypedDict": ".entity_balance",
    "EntityBalancePendingAmount": ".entity_balance",
    "EntityBalancePendingAmountTypedDict": ".entity_balance",
    "EntityBalanceStatus": ".entity_balance",
    "EntityBalanceTransferDestination": ".entity_balance",
    "EntityBalanceTransferDestinationTypedDict": ".entity_balance",
    "EntityBalanceTransferFrequency": ".entity_balance",
    "EntityBalanceTransferThreshold": ".entity_balance",
    "EntityBalanceTransferThresholdTypedDict": ".entity_balance",
    "EntityBalanceTypedDict": ".entity_balance",
    "AvailableBalance": ".entity_balance_report",
    "AvailableBalanceTypedDict": ".entity_balance_report",
    "Capital": ".entity_balance_report",
    "CapitalTypedDict": ".entity_balance_report",
    "Chargebacks": ".entity_balance_report",
    "ChargebacksTypedDict": ".entity_balance_report",
    "Close": ".entity_balance_report",
    "CloseTypedDict": ".entity_balance_report",
    "Corrections": ".entity_balance_report",
    "CorrectionsTypedDict": ".entity_balance_report",
    "EntityBalanceReport": ".entity_balance_report",
    "EntityBalanceReportLinks": ".entity_balance_report",
    "EntityBalanceReportLinksTypedDict": ".entity_balance_report",
    "EntityBalanceReportTypedDict": ".entity_balance_report",
    "FeePrepayments": ".entity_balance_report",
    "FeePrepaymentsTypedDict": ".entity_balance_report",
    "Open": ".entity_balance_report",
    "OpenTypedDict": ".entity_balance_report",
    "Payments": ".entity_balance_report",
    "PaymentsTypedDict": ".entity_balance_report",
    "PendingBalance": ".entity_balance_report",
    "PendingBalanceTypedDict": ".entity_balance_report",
    "Refunds": ".entity_balance_report",
    "RefundsTypedDict": ".entity_balance_report",
    "Topups": ".entity_balance_report",
    "TopupsTypedDict": ".entity_balance_report",
    "Totals": ".entity_balance_report",
    "TotalsTypedDict": ".entity_balance_report",
    "Transfers": ".entity_balance_report",
    "TransfersTypedDict": ".entity_balance_report",
    "CanceledOutgoingTransfer": ".entity_balance_transaction",
    "CanceledOutgoingTransferTypedDict": ".entity_balance_transaction",
    "Capture": ".entity_balance_transaction",
    "CaptureCommision": ".entity_balance_transaction",
    "CaptureCommisionTypedDict": ".entity_balance_transaction",
    "CaptureRollingReserveRelease": ".entity_balance_transaction",
    "CaptureRollingReserveReleaseTypedDict": ".entity_balance_transaction",
    "CaptureTypedDict": ".entity_balance_transaction",
    "Chargeback": ".entity_balance_transaction",
    "ChargebackCompensation": ".entity_balance_transaction",
    "ChargebackCompensationTypedDict": ".entity_balance_transaction",
    "ChargebackReversal": ".entity_balance_transaction",
    "ChargebackReversalTypedDict": ".entity_balance_transaction",
    "ChargebackTypedDict": ".entity_balance_transaction",
    "Context": ".entity_balance_transaction",
    "ContextTypedDict": ".entity_balance_transaction",
    "DeductionDetails": ".entity_balance_transaction",
    "DeductionDetailsTypedDict": ".entity_balance_transaction",
    "EntityBalanceTransaction": ".entity_balance_transaction",
    "EntityBalanceTransactionApplicationFee": ".entity_balance_transaction",
    "EntityBalanceTransactionApplicationFeeTypedDict": ".entity_balance_transaction",
    "EntityBalanceTransactionPayment": ".entity_balance_transaction",
    "EntityBalanceTransactionPaymentTypedDict": ".entity_balance_transaction",
    "EntityBalanceTransactionTypedDict": ".entity_balance_transaction",
    "FailedPayment": ".entity_balance_transaction",
    "FailedPaymentFee": ".entity_balance_transaction",
    "FailedPaymentFeeTypedDict": ".entity_balance_transaction",
    "FailedPaymentTypedDict": ".entity_balance_transaction",
    "InvoiceCompensation": ".entity_balance_transaction",
    "InvoiceCompensationTypedDict": ".entity_balance_transaction",
    "ManagedFee": ".entity_balance_transaction",
    "ManagedFeeTypedDict": ".entity_balance_transaction",
    "OutgoingTransfer": ".entity_balance_transaction",
    "OutgoingTransferTypedDict": ".entity_balance_transaction",
    "PaymentCommission": ".entity_balance_transaction",
    "PaymentCommissionTypedDict": ".entity_balance_transaction",
    "PaymentFee": ".entity_balance_transaction",
    "PaymentFeeTypedDict": ".entity_balance_transaction",
    "PlatformPaymentChargeback": ".entity_balance_transaction",
    "PlatformPaymentChargebackTypedDict": ".entity_balance_transaction",
    "PlatformPaymentRefund": ".entity_balance_transaction",
    "PlatformPaymentRefundTypedDict": ".entity_balance_transaction",
    "PostPaymentSplitPayment": ".entity_balance_transaction",
    "PostPaymentSplitPaymentTypedDict": ".entity_balance_transaction",
    "Refund": ".entity_balance_transaction",
    "RefundCompensation": ".entity_balance_transaction",
    "RefundCompensationTypedDict": ".entity_balance_transaction",
    "RefundTypedDict": ".entity_balance_transaction",
    "ReimbursementFee": ".entity_balance_transaction",
    "ReimbursementFeeTypedDict": ".entity_balance_transaction",
    "ReturnedManagedFee": ".entity_balance_transaction",
    "ReturnedManagedFeeTypedDict": ".entity_balance_transaction",
    "ReturnedPlatformPaymentRefund": ".entity_balance_transaction",
    "ReturnedPlatformPaymentRefundTypedDict": ".entity_balance_transaction",
    "ReturnedRefund": ".entity_balance_transaction",
    "ReturnedRefundCompensation": ".entity_balance_transaction",
    "ReturnedRefundCompensationTypedDict": ".entity_balance_transaction",
    "ReturnedRefundTypedDict": ".entity_balance_transaction",
    "ReturnedTransfer": ".entity_balance_transaction",
    "ReturnedTransferTypedDict": ".entity_balance_transaction",
    "ReversedChargebackCompensation": ".entity_balance_transaction",
    "ReversedChargebackCompensationTypedDict": ".entity_balance_transaction",
    "ReversedPlatformPaymentChargeback": ".entity_balance_transaction",
    "ReversedPlatformPaymentChargebackTypedDict": ".entity_balance_transaction",
    "SplitPayment": ".entity_balance_transaction",
    "SplitPaymentTypedDict": ".entity_balance_transaction",
    "UnauthorizedDirectDebit": ".entity_balance_transaction",
    "UnauthorizedDirectDebitTypedDict": ".entity_balance_transaction",
    "EntityBalanceTransfer": ".entity_balance_transfer",
    "EntityBalanceTransferTypedDict": ".entity_balance_transfer",
    "EntityBalanceTransferParty": ".entity_balance_transfer_party",
    "EntityBalanceTransferPartyTypedDict": ".entity_balance_transfer_party",
    "EntityBalanceTransferPartyResponse": ".entity_balance_transfer_party_response",
    "EntityBalanceTransferPartyResponseTypedDict": ".entity_balance_transfer_party_response",
    "EntityBalanceTransferResponse": ".entity_balance_transfer_response",
    "EntityBalanceTransferResponseStatusReason": ".entity_balance_transfer_response",
    "EntityBalanceTransferResponseStatusReasonTypedDict": ".entity_balance_transfer_response",
    "EntityBalanceTransferResponseTypedDict": ".entity_balance_transfer_response",
    "EntityCapability": ".entity_capability",
    "EntityCapabilityTypedDict": ".entity_capability",
    "EntityCapabilityRequirement": ".entity_capability_requirement",
    "EntityCapabilityRequirementLinks": ".entity_capability_requirement",
    "EntityCapabilityRequirementLinksTypedDict": ".entity_capability_requirement",
    "EntityCapabilityRequirementTypedDict": ".entity_capability_requirement",
    "EntityCapture": ".entity_capture",
    "EntityCaptureTypedDict": ".entity_capture",
    "EntityChargeback": ".entity_chargeback",
    "EntityChargebackLinks": ".entity_chargeback",
    "EntityChargebackLinksTypedDict": ".entity_chargeback",
    "EntityChargebackReason": ".entity_chargeback",
    "EntityChargebackReasonTypedDict": ".entity_chargeback",
    "EntityChargebackSettlementAmount": ".entity_chargeback",
    "EntityChargebackSettlementAmountTypedDict": ".entity_chargeback",
    "EntityChargebackTypedDict": ".entity_chargeback",
    "EntityCustomer": ".entity_customer",
    "EntityCustomerTypedDict": ".entity_customer",
    "EntityEvent": ".entity_event",
    "EntityEventLinks": ".entity_event",
    "EntityEventLinksTypedDict": ".entity_event",
    "EntityEventTypedDict": ".entity_event",
    "EntityInvoice": ".entity_invoice",
    "EntityInvoiceGrossAmount": ".entity_invoice",
    "EntityInvoiceGrossAmountTypedDict": ".entity_invoice",
    "EntityInvoiceLine": ".entity_invoice",
    "EntityInvoiceLineTypedDict": ".entity_invoice",
    "EntityInvoiceLinks": ".entity_invoice",
    "EntityInvoiceLinksTypedDict": ".entity_invoice",
    "EntityInvoiceNetAmount": ".entity_invoice",
    "EntityInvoiceNetAmountTypedDict": ".entity_invoice",
    "EntityInvoiceStatus": ".entity_invoice",
    "EntityInvoiceTypedDict": ".entity_invoice",
    "EntityInvoiceVatAmount": ".entity_invoice",
    "EntityInvoiceVatAmountTypedDict": ".entity_invoice",
    "EntityMethodGet": ".entity_method_get",
    "EntityMethodGetID": ".entity_method_get",
    "EntityMethodGetImage": ".entity_method_get",
    "EntityMethodGetImageTypedDict": ".entity_method_get",
    "EntityMethodGetIssuer": ".entity_method_get",
    "EntityMethodGetIssuerImage": ".entity_method_get",
    "EntityMethodGetIssuerImageTypedDict": ".entity_method_get",
    "EntityMethodGetIssuerTypedDict": ".entity_method_get",
    "EntityMethodGetLinks": ".entity_method_get",
    "EntityMethodGetLinksTypedDict": ".entity_method_get",
    "EntityMethodGetMaximumAmount": ".entity_method_get",
    "EntityMethodGetMaximumAmountTypedDict": ".entity_method_get",
    "EntityMethodGetMinimumAmount": ".entity_method_get",
    "EntityMethodGetMinimumAmountTypedDict": ".entity_method_get",
    "EntityMethodGetTypedDict": ".entity_method_get",
    "EntityOnboardingStatus": ".entity_onboarding_status",
    "EntityOnboardingStatusLinks": ".entity_onboarding_status",
    "EntityOnboardingStatusLinksTypedDict": ".entity_onboarding_status",
    "EntityOnboardingStatusStatus": ".entity_onboarding_status",
    "EntityOnboardingStatusTypedDict": ".entity_onboarding_status",
    "EntityOrganization": ".entity_organization",
    "EntityOrganizationLinks": ".entity_organization",
    "EntityOrganizationLinksTypedDict": ".entity_organization",
    "EntityOrganizationLocale": ".entity_organization",
    "EntityOrganizationTypedDict": ".entity_organization",
    "EntityPaymentRoute": ".entity_payment_route",
    "EntityPaymentRouteDestination": ".entity_payment_route",
    "EntityPaymentRouteDestinationTypedDict": ".entity_payment_route",
    "EntityPaymentRouteLinks": ".entity_payment_route",
    "EntityPaymentRouteLinksTypedDict": ".entity_payment_route",
    "EntityPaymentRouteTypedDict": ".entity_payment_route",
    "EntityPaymentRouteResponse": ".entity_payment_route_response",
    "EntityPaymentRouteResponseDestination": ".entity_payment_route_response",
    "EntityPaymentRouteResponseDestinationTypedDict": ".entity_payment_route_response",
    "EntityPaymentRouteResponseLinks": ".entity_payment_route_response",
    "EntityPaymentRouteResponseLinksTypedDict": ".entity_payment_route_response",
    "EntityPaymentRouteResponseTypedDict": ".entity_payment_route_response",
    "EntityPermission": ".entity_permission",
    "EntityPermissionLinks": ".entity_permission",
    "EntityPermissionLinksTypedDict": ".entity_permission",
    "EntityPermissionTypedDict": ".entity_permission",
    "EntityRefundResponse": ".entity_refund_response",
    "EntityRefundResponseExternalReference": ".entity_refund_response",
    "EntityRefundResponseExternalReferenceTypedDict": ".entity_refund_response",
    "EntityRefundResponseLinks": ".entity_refund_response",
    "EntityRefundResponseLinksTypedDict": ".entity_refund_response",
    "EntityRefundResponseRoutingReversal": ".entity_refund_response",
    "EntityRefundResponseRoutingReversalTypedDict": ".entity_refund_response",
    "EntityRefundResponseSettlementAmount": ".entity_refund_response",
    "EntityRefundResponseSettlementAmountTypedDict": ".entity_refund_response",
    "EntityRefundResponseSource": ".entity_refund_response",
    "EntityRefundResponseSourceTypedDict": ".entity_refund_response",
    "EntityRefundResponseStatus": ".entity_refund_response",
    "EntityRefundResponseTypedDict": ".entity_refund_response",
    "EntitySettlement": ".entity_settlement",
    "EntitySettlementAmount": ".entity_settlement",
    "EntitySettlementAmountTypedDict": ".entity_settlement",
    "EntitySettlementCost": ".entity_settlement",
    "EntitySettlementCostTypedDict": ".entity_settlement",
    "EntitySettlementLinks": ".entity_settlement",
    "EntitySettlementLinksTypedDict": ".entity_settlement",
    "EntitySettlementPeriods": ".entity_settlement",
    "EntitySettlementPeriodsTypedDict": ".entity_settlement",
    "EntitySettlementRate": ".entity_settlement",
    "EntitySettlementRateTypedDict": ".entity_settlement",
    "EntitySettlementRevenue": ".entity_settlement",
    "EntitySettlementRevenueTypedDict": ".entity_settlement",
    "EntitySettlementStatus": ".entity_settlement",
    "EntitySettlementTypedDict": ".entity_settlement",
    "EntityTerminal": ".entity_terminal",
    "EntityTerminalLinks": ".entity_terminal",
    "EntityTerminalLinksTypedDict": ".entity_terminal",
    "EntityTerminalStatus": ".entity_terminal",
    "EntityTerminalTypedDict": ".entity_terminal",
    "EntityWebhook": ".entity_webhook",
    "EntityWebhookLinks": ".entity_webhook",
    "EntityWebhookLinksTypedDict": ".entity_webhook",
    "EntityWebhookTypedDict": ".entity_webhook",
    "Embedded": ".entity_webhook_event",
    "EmbeddedTypedDict": ".entity_webhook_event",
    "Entity": ".entity_webhook_event",
    "EntityTypedDict": ".entity_webhook_event",
    "EntityWebhookEvent": ".entity_webhook_event",
    "EntityWebhookEventLinks": ".entity_webhook_event",
    "EntityWebhookEventLinksTypedDict": ".entity_webhook_event",
    "EntityWebhookEventTypedDict": ".entity_webhook_event",
    "EntityWebhookEventWebhookEventTypes": ".entity_webhook_event",
    "Documentation": ".error_response",
    "DocumentationTypedDict": ".error_response",
    "ErrorResponse": ".error_response",
    "ErrorResponseData": ".error_response",
    "ErrorsLinks": ".error_response",
    "ErrorsLinksTypedDict": ".error_response",
    "GetBalanceReportGlobals": ".get_balance_reportop",
    "GetBalanceReportGlobalsTypedDict": ".get_balance_reportop",
    "GetBalanceReportRequest": ".get_balance_reportop",
    "GetBalanceReportRequestTypedDict": ".get_balance_reportop",
    "GetBalanceGlobals": ".get_balanceop",
    "GetBalanceGlobalsTypedDict": ".get_balanceop",
    "GetBalanceRequest": ".get_balanceop",
    "GetBalanceRequestTypedDict": ".get_balanceop",
    "GetCaptureGlobals": ".get_captureop",
    "GetCaptureGlobalsTypedDict": ".get_captureop",
    "GetCaptureRequest": ".get_captureop",
    "GetCaptureRequestTypedDict": ".get_captureop",
    "GetChargebackGlobals": ".get_chargebackop",
    "GetChargebackGlobalsTypedDict": ".get_chargebackop",
    "GetChargebackRequest": ".get_chargebackop",
    "GetChargebackRequestTypedDict": ".get_chargebackop",
    "GetClientCommission": ".get_clientop",
    "GetClientCommissionTypedDict": ".get_clientop",
    "GetClientEmbedded": ".get_clientop",
    "GetClientEmbeddedTypedDict": ".get_clientop",
    "GetClientLinks": ".get_clientop",
    "GetClientLinksTypedDict": ".get_clientop",
    "GetClientRequest": ".get_clientop",
    "GetClientRequestTypedDict": ".get_clientop",
    "GetClientResponse": ".get_clientop",
    "GetClientResponseTypedDict": ".get_clientop",
    "GetConnectBalanceTransferGlobals": ".get_connect_balance_transferop",
    "GetConnectBalanceTransferGlobalsTypedDict": ".get_connect_balance_transferop",
    "GetConnectBalanceTransferRequest": ".get_connect_balance_transferop",
    "GetConnectBalanceTransferRequestTypedDict": ".get_connect_balance_transferop",
    "GetCurrentOrganizationRequest": ".get_current_organizationop",
    "GetCurrentOrganizationRequestTypedDict": ".get_current_organizationop",
    "GetCurrentProfileRequest": ".get_current_profileop",
    "GetCurrentProfileRequestTypedDict": ".get_current_profileop",
    "GetCustomerGlobals": ".get_customerop",
    "GetCustomerGlobalsTypedDict": ".get_customerop",
    "GetCustomerLinks": ".get_customerop",
    "GetCustomerLinksTypedDict": ".get_customerop",
    "GetCustomerRequest": ".get_customerop",
    "GetCustomerRequestTypedDict": ".get_customerop",
    "GetCustomerResponse": ".get_customerop",
    "GetCustomerResponseTypedDict": ".get_customerop",
    "GetInvoiceRequest": ".get_invoiceop",
    "GetInvoiceRequestTypedDict": ".get_invoiceop",
    "GetMandateGlobals": ".get_mandateop",
    "GetMandateGlobalsTypedDict": ".get_mandateop",
    "GetMandateRequest": ".get_mandateop",
    "GetMandateRequestTypedDict": ".get_mandateop",
    "GetMethodGlobals": ".get_methodop",
    "GetMethodGlobalsTypedDict": ".get_methodop",
    "GetMethodRequest": ".get_methodop",
    "GetMethodRequestTypedDict": ".get_methodop",
    "GetNextSettlementRequest": ".get_next_settlementop",
    "GetNextSettlementRequestTypedDict": ".get_next_settlementop",
    "GetOnboardingStatusRequest": ".get_onboarding_statusop",
    "GetOnboardingStatusRequestTypedDict": ".get_onboarding_statusop",
    "GetOpenSettlementRequest": ".get_open_settlementop",
    "GetOpenSettlementRequestTypedDict": ".get_open_settlementop",
    "GetOrganizationGlobals": ".get_organizationop",
    "GetOrganizationGlobalsTypedDict": ".get_organizationop",
    "GetOrganizationRequest": ".get_organizationop",
    "GetOrganizationRequestTypedDict": ".get_organizationop",
    "GetPartnerStatusLinks": ".get_partner_statusop",
    "GetPartnerStatusLinksTypedDict": ".get_partner_statusop",
    "GetPartnerStatusRequest": ".get_partner_statusop",
    "GetPartnerStatusRequestTypedDict": ".get_partner_statusop",
    "GetPartnerStatusResponse": ".get_partner_statusop",
    "GetPartnerStatusResponseTypedDict": ".get_partner_statusop",
    "PartnerType": ".get_partner_statusop",
    "UserAgentToken": ".get_partner_statusop",
    "UserAgentTokenTypedDict": ".get_partner_statusop",
    "GetPaymentLinkPaymentsEmbedded": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsEmbeddedTypedDict": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsGlobals": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsGlobalsTypedDict": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsRequest": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsRequestTypedDict": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsResponse": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsResponseBody": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsResponseBodyTypedDict": ".get_payment_link_paymentsop",
    "GetPaymentLinkPaymentsResponseTypedDict": ".get_payment_link_paymentsop",
    "GetPaymentLinkGlobals": ".get_payment_linkop",
    "GetPaymentLinkGlobalsTypedDict": ".get_payment_linkop",
    "GetPaymentLinkRequest": ".get_payment_linkop",
    "GetPaymentLinkRequestTypedDict": ".get_payment_linkop",
    "GetPaymentGlobals": ".get_paymentop",
    "GetPaymentGlobalsTypedDict": ".get_paymentop",
    "GetPaymentRequest": ".get_paymentop",
    "GetPaymentRequestTypedDict": ".get_paymentop",
    "GetPermissionGlobals": ".get_permissionop",
    "GetPermissionGlobalsTypedDict": ".get_permissionop",
    "GetPermissionRequest": ".get_permissionop",
    "GetPermissionRequestTypedDict": ".get_permissionop",
    "GetPrimaryBalanceRequest": ".get_primary_balanceop",
    "GetPrimaryBalanceRequestTypedDict": ".get_primary_balanceop",
    "GetProfileGlobals": ".get_profileop",
    "GetProfileGlobalsTypedDict": ".get_profileop",
    "GetProfileRequest": ".get_profileop",
    "GetProfileRequestTypedDict": ".get_profileop",
    "GetRefundGlobals": ".get_refundop",
    "GetRefundGlobalsTypedDict": ".get_refundop",
    "GetRefundRequest": ".get_refundop",
    "GetRefundRequestTypedDict": ".get_refundop",
    "GetSalesInvoiceGlobals": ".get_sales_invoiceop",
    "GetSalesInvoiceGlobalsTypedDict": ".get_sales_invoiceop",
    "GetSalesInvoiceRequest": ".get_sales_invoiceop",
    "GetSalesInvoiceRequestTypedDict": ".get_sales_invoiceop",
    "GetSessionRequest": ".get_sessionop",
    "GetSessionRequestTypedDict": ".get_sessionop",
    "GetSettlementRequest": ".get_settlementop",
    "GetSettlementRequestTypedDict": ".get_settlementop",
    "GetSubscriptionGlobals": ".get_subscriptionop",
    "GetSubscriptionGlobalsTypedDict": ".get_subscriptionop",
    "GetSubscriptionRequest": ".get_subscriptionop",
    "GetSubscriptionRequestTypedDict": ".get_subscriptionop",
    "GetTerminalGlobals": ".get_terminalop",
    "GetTerminalGlobalsTypedDict": ".get_terminalop",
    "GetTerminalRequest": ".get_terminalop",
    "GetTerminalRequestTypedDict": ".get_terminalop",
    "GetWebhookEventGlobals": ".get_webhook_eventop",
    "GetWebhookEventGlobalsTypedDict": ".get_webhook_eventop",
    "GetWebhookEventRequest": ".get_webhook_eventop",
    "GetWebhookEventRequestTypedDict": ".get_webhook_eventop",
    "GetWebhookGlobals": ".get_webhookop",
    "GetWebhookGlobalsTypedDict": ".get_webhookop",
    "GetWebhookRequest": ".get_webhookop",
    "GetWebhookRequestTypedDict": ".get_webhookop",
    "LineCategories": ".line_categories",
    "LineCategoriesResponse": ".line_categories_response",
    "ListAllChargebacksEmbedded": ".list_all_chargebacksop",
    "ListAllChargebacksEmbeddedTypedDict": ".list_all_chargebacksop",
    "ListAllChargebacksGlobals": ".list_all_chargebacksop",
    "ListAllChargebacksGlobalsTypedDict": ".list_all_chargebacksop",
    "ListAllChargebacksRequest": ".list_all_chargebacksop",
    "ListAllChargebacksRequestTypedDict": ".list_all_chargebacksop",
    "ListAllChargebacksResponse": ".list_all_chargebacksop",
    "ListAllChargebacksResponseBody": ".list_all_chargebacksop",
    "ListAllChargebacksResponseBodyTypedDict": ".list_all_chargebacksop",
    "ListAllChargebacksResponseTypedDict": ".list_all_chargebacksop",
    "ListAllMethodsEmbedded": ".list_all_methodsop",
    "ListAllMethodsEmbeddedTypedDict": ".list_all_methodsop",
    "ListAllMethodsGlobals": ".list_all_methodsop",
    "ListAllMethodsGlobalsTypedDict": ".list_all_methodsop",
    "ListAllMethodsLinks": ".list_all_methodsop",
    "ListAllMethodsLinksTypedDict": ".list_all_methodsop",
    "ListAllMethodsRequest": ".list_all_methodsop",
    "ListAllMethodsRequestTypedDict": ".list_all_methodsop",
    "ListAllMethodsResponse": ".list_all_methodsop",
    "ListAllMethodsResponseTypedDict": ".list_all_methodsop",
    "ListAllRefundsEmbedded": ".list_all_refundsop",
    "ListAllRefundsEmbeddedTypedDict": ".list_all_refundsop",
    "ListAllRefundsGlobals": ".list_all_refundsop",
    "ListAllRefundsGlobalsTypedDict": ".list_all_refundsop",
    "ListAllRefundsRequest": ".list_all_refundsop",
    "ListAllRefundsRequestTypedDict": ".list_all_refundsop",
    "ListAllRefundsResponse": ".list_all_refundsop",
    "ListAllRefundsResponseBody": ".list_all_refundsop",
    "ListAllRefundsResponseBodyTypedDict": ".list_all_refundsop",
    "ListAllRefundsResponseTypedDict": ".list_all_refundsop",
    "ListAllSubscriptionsEmbedded": ".list_all_subscriptionsop",
    "ListAllSubscriptionsEmbeddedTypedDict": ".list_all_subscriptionsop",
    "ListAllSubscriptionsGlobals": ".list_all_subscriptionsop",
    "ListAllSubscriptionsGlobalsTypedDict": ".list_all_subscriptionsop",
    "ListAllSubscriptionsRequest": ".list_all_subscriptionsop",
    "ListAllSubscriptionsRequestTypedDict": ".list_all_subscriptionsop",
    "ListAllSubscriptionsResponse": ".list_all_subscriptionsop",
    "ListAllSubscriptionsResponseBody": ".list_all_subscriptionsop",
    "ListAllSubscriptionsResponseBodyTypedDict": ".list_all_subscriptionsop",
    "ListAllSubscriptionsResponseTypedDict": ".list_all_subscriptionsop",
    "ListBalanceTransactionsEmbedded": ".list_balance_transactionsop",
    "ListBalanceTransactionsEmbeddedTypedDict": ".list_balance_transactionsop",
    "ListBalanceTransactionsGlobals": ".list_balance_transactionsop",
    "ListBalanceTransactionsGlobalsTypedDict": ".list_balance_transactionsop",
    "ListBalanceTransactionsRequest": ".list_balance_transactionsop",
    "ListBalanceTransactionsRequestTypedDict": ".list_balance_transactionsop",
    "ListBalanceTransactionsResponse": ".list_balance_transactionsop",
    "ListBalanceTransactionsResponseBody": ".list_balance_transactionsop",
    "ListBalanceTransactionsResponseBodyTypedDict": ".list_balance_transactionsop",
    "ListBalanceTransactionsResponseTypedDict": ".list_balance_transactionsop",
    "ListBalancesEmbedded": ".list_balancesop",
    "ListBalancesEmbeddedTypedDict": ".list_balancesop",
    "ListBalancesGlobals": ".list_balancesop",
    "ListBalancesGlobalsTypedDict": ".list_balancesop",
    "ListBalancesRequest": ".list_balancesop",
    "ListBalancesRequestTypedDict": ".list_balancesop",
    "ListBalancesResponse": ".list_balancesop",
    "ListBalancesResponseBody": ".list_balancesop",
    "ListBalancesResponseBodyTypedDict": ".list_balancesop",
    "ListBalancesResponseTypedDict": ".list_balancesop",
    "ListCapabilitiesEmbedded": ".list_capabilitiesop",
    "ListCapabilitiesEmbeddedTypedDict": ".list_capabilitiesop",
    "ListCapabilitiesLinks": ".list_capabilitiesop",
    "ListCapabilitiesLinksTypedDict": ".list_capabilitiesop",
    "ListCapabilitiesRequest": ".list_capabilitiesop",
    "ListCapabilitiesRequestTypedDict": ".list_capabilitiesop",
    "ListCapabilitiesResponse": ".list_capabilitiesop",
    "ListCapabilitiesResponseTypedDict": ".list_capabilitiesop",
    "ListCaptureResponse": ".list_capture_response",
    "ListCaptureResponseLinks": ".list_capture_response",
    "ListCaptureResponseLinksTypedDict": ".list_capture_response",
    "ListCaptureResponseSettlementAmount": ".list_capture_response",
    "ListCaptureResponseSettlementAmountTypedDict": ".list_capture_response",
    "ListCaptureResponseStatus": ".list_capture_response",
    "ListCaptureResponseTypedDict": ".list_capture_response",
    "ListCapturesEmbedded": ".list_capturesop",
    "ListCapturesEmbeddedTypedDict": ".list_capturesop",
    "ListCapturesGlobals": ".list_capturesop",
    "ListCapturesGlobalsTypedDict": ".list_capturesop",
    "ListCapturesRequest": ".list_capturesop",
    "ListCapturesRequestTypedDict": ".list_capturesop",
    "ListCapturesResponse": ".list_capturesop",
    "ListCapturesResponseBody": ".list_capturesop",
    "ListCapturesResponseBodyTypedDict": ".list_capturesop",
    "ListCapturesResponseTypedDict": ".list_capturesop",
    "ListChargebacksEmbedded": ".list_chargebacksop",
    "ListChargebacksEmbeddedTypedDict": ".list_chargebacksop",
    "ListChargebacksGlobals": ".list_chargebacksop",
    "ListChargebacksGlobalsTypedDict": ".list_chargebacksop",
    "ListChargebacksRequest": ".list_chargebacksop",
    "ListChargebacksRequestTypedDict": ".list_chargebacksop",
    "ListChargebacksResponse": ".list_chargebacksop",
    "ListChargebacksResponseBody": ".list_chargebacksop",
    "ListChargebacksResponseBodyTypedDict": ".list_chargebacksop",
    "ListChargebacksResponseTypedDict": ".list_chargebacksop",
    "ClientEmbedded": ".list_clientsop",
    "ClientEmbeddedTypedDict": ".list_clientsop",
    "ListClientsClient": ".list_clientsop",
    "ListClientsClientTypedDict": ".list_clientsop",
    "ListClientsCommission": ".list_clientsop",
    "ListClientsCommissionTypedDict": ".list_clientsop",
    "ListClientsEmbedded": ".list_clientsop",
    "ListClientsEmbeddedTypedDict": ".list_clientsop",
    "ListClientsLinks": ".list_clientsop",
    "ListClientsLinksTypedDict": ".list_clientsop",
    "ListClientsRequest": ".list_clientsop",
    "ListClientsRequestTypedDict": ".list_clientsop",
    "ListClientsResponse": ".list_clientsop",
    "ListClientsResponseBody": ".list_clientsop",
    "ListClientsResponseBodyTypedDict": ".list_clientsop",
    "ListClientsResponseTypedDict": ".list_clientsop",
    "ListConnectBalanceTransfersEmbedded": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersEmbeddedTypedDict": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersGlobals": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersGlobalsTypedDict": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersRequest": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersRequestTypedDict": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersResponse": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersResponseBody": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersResponseBodyTypedDict": ".list_connect_balance_transfersop",
    "ListConnectBalanceTransfersResponseTypedDict": ".list_connect_balance_transfersop",
    "ListCustomerPaymentsEmbedded": ".list_customer_paymentsop",
    "ListCustomerPaymentsEmbeddedTypedDict": ".list_customer_paymentsop",
    "ListCustomerPaymentsGlobals": ".list_customer_paymentsop",
    "ListCustomerPaymentsGlobalsTypedDict": ".list_customer_paymentsop",
    "ListCustomerPaymentsRequest": ".list_customer_paymentsop",
    "ListCustomerPaymentsRequestTypedDict": ".list_customer_paymentsop",
    "ListCustomerPaymentsResponse": ".list_customer_paymentsop",
    "ListCustomerPaymentsResponseBody": ".list_customer_paymentsop",
    "ListCustomerPaymentsResponseBodyTypedDict": ".list_customer_paymentsop",
    "ListCustomerPaymentsResponseTypedDict": ".list_customer_paymentsop",
    "ListCustomerResponse": ".list_customer_response",
    "ListCustomerResponseLinks": ".list_customer_response",
    "ListCustomerResponseLinksTypedDict": ".list_customer_response",
    "ListCustomerResponseTypedDict": ".list_customer_response",
    "ListCustomersEmbedded": ".list_customersop",
    "ListCustomersEmbeddedTypedDict": ".list_customersop",
    "ListCustomersGlobals": ".list_customersop",
    "ListCustomersGlobalsTypedDict": ".list_customersop",
    "ListCustomersRequest": ".list_customersop",
    "ListCustomersRequestTypedDict": ".list_customersop",
    "ListCustomersResponse": ".list_customersop",
    "ListCustomersResponseBody": ".list_customersop",
    "ListCustomersResponseBodyTypedDict": ".list_customersop",
    "ListCustomersResponseTypedDict": ".list_customersop",
    "ListEntityBalance": ".list_entity_balance",
    "ListEntityBalanceAvailableAmount": ".list_entity_balance",
    "ListEntityBalanceAvailableAmountTypedDict": ".list_entity_balance",
    "ListEntityBalanceCurrency": ".list_entity_balance",
    "ListEntityBalanceLinks": ".list_entity_balance",
    "ListEntityBalanceLinksTypedDict": ".list_entity_balance",
    "ListEntityBalancePendingAmount": ".list_entity_balance",
    "ListEntityBalancePendingAmountTypedDict": ".list_entity_balance",
    "ListEntityBalanceStatus": ".list_entity_balance",
    "ListEntityBalanceTransferDestination": ".list_entity_balance",
    "ListEntityBalanceTransferDestinationTypedDict": ".list_entity_balance",
    "ListEntityBalanceTransferFrequency": ".list_entity_balance",
    "ListEntityBalanceTransferThreshold": ".list_entity_balance",
    "ListEntityBalanceTransferThresholdTypedDict": ".list_entity_balance",
    "ListEntityBalanceTypedDict": ".list_entity_balance",
    "ListEntityChargeback": ".list_entity_chargeback",
    "ListEntityChargebackLinks": ".list_entity_chargeback",
    "ListEntityChargebackLinksTypedDict": ".list_entity_chargeback",
    "ListEntityChargebackReason": ".list_entity_chargeback",
    "ListEntityChargebackReasonTypedDict": ".list_entity_chargeback",
    "ListEntityChargebackSettlementAmount": ".list_entity_chargeback",
    "ListEntityChargebackSettlementAmountTypedDict": ".list_entity_chargeback",
    "ListEntityChargebackTypedDict": ".list_entity_chargeback",
    "ListEntityInvoice": ".list_entity_invoice",
    "ListEntityInvoiceGrossAmount": ".list_entity_invoice",
    "ListEntityInvoiceGrossAmountTypedDict": ".list_entity_invoice",
    "ListEntityInvoiceLine": ".list_entity_invoice",
    "ListEntityInvoiceLineTypedDict": ".list_entity_invoice",
    "ListEntityInvoiceLinks": ".list_entity_invoice",
    "ListEntityInvoiceLinksTypedDict": ".list_entity_invoice",
    "ListEntityInvoiceNetAmount": ".list_entity_invoice",
    "ListEntityInvoiceNetAmountTypedDict": ".list_entity_invoice",
    "ListEntityInvoiceStatus": ".list_entity_invoice",
    "ListEntityInvoiceTypedDict": ".list_entity_invoice",
    "ListEntityInvoiceVatAmount": ".list_entity_invoice",
    "ListEntityInvoiceVatAmountTypedDict": ".list_entity_invoice",
    "ListEntityMethod": ".list_entity_method",
    "ListEntityMethodID": ".list_entity_method",
    "ListEntityMethodImage": ".list_entity_method",
    "ListEntityMethodImageTypedDict": ".list_entity_method",
    "ListEntityMethodIssuer": ".list_entity_method",
    "ListEntityMethodIssuerImage": ".list_entity_method",
    "ListEntityMethodIssuerImageTypedDict": ".list_entity_method",
    "ListEntityMethodIssuerTypedDict": ".list_entity_method",
    "ListEntityMethodLinks": ".list_entity_method",
    "ListEntityMethodLinksTypedDict": ".list_entity_method",
    "ListEntityMethodMaximumAmount": ".list_entity_method",
    "ListEntityMethodMaximumAmountTypedDict": ".list_entity_method",
    "ListEntityMethodMinimumAmount": ".list_entity_method",
    "ListEntityMethodMinimumAmountTypedDict": ".list_entity_method",
    "ListEntityMethodTypedDict": ".list_entity_method",
    "ListEntityMethodAll": ".list_entity_method_all",
    "ListEntityMethodAllID": ".list_entity_method_all",
    "ListEntityMethodAllImage": ".list_entity_method_all",
    "ListEntityMethodAllImageTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllIssuer": ".list_entity_method_all",
    "ListEntityMethodAllIssuerImage": ".list_entity_method_all",
    "ListEntityMethodAllIssuerImageTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllIssuerTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllLinks": ".list_entity_method_all",
    "ListEntityMethodAllLinksTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllMaximumAmount": ".list_entity_method_all",
    "ListEntityMethodAllMaximumAmountTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllMinimumAmount": ".list_entity_method_all",
    "ListEntityMethodAllMinimumAmountTypedDict": ".list_entity_method_all",
    "ListEntityMethodAllTypedDict": ".list_entity_method_all",
    "Pricing": ".list_entity_method_all",
    "PricingTypedDict": ".list_entity_method_all",
    "ListEntityPermission": ".list_entity_permission",
    "ListEntityPermissionLinks": ".list_entity_permission",
    "ListEntityPermissionLinksTypedDict": ".list_entity_permission",
    "ListEntityPermissionTypedDict": ".list_entity_permission",
    "ListEntityRefund": ".list_entity_refund",
    "ListEntityRefundExternalReference": ".list_entity_refund",
    "ListEntityRefundExternalReferenceTypedDict": ".list_entity_refund",
    "ListEntityRefundLinks": ".list_entity_refund",
    "ListEntityRefundLinksTypedDict": ".list_entity_refund",
    "ListEntityRefundRoutingReversal": ".list_entity_refund",
    "ListEntityRefundRoutingReversalTypedDict": ".list_entity_refund",
    "ListEntityRefundSettlementAmount": ".list_entity_refund",
    "ListEntityRefundSettlementAmountTypedDict": ".list_entity_refund",
    "ListEntityRefundSource": ".list_entity_refund",
    "ListEntityRefundSourceTypedDict": ".list_entity_refund",
    "ListEntityRefundStatus": ".list_entity_refund",
    "ListEntityRefundTypedDict": ".list_entity_refund",
    "ListEntitySettlement": ".list_entity_settlement",
    "ListEntitySettlementAmount": ".list_entity_settlement",
    "ListEntitySettlementAmountTypedDict": ".list_entity_settlement",
    "ListEntitySettlementCost": ".list_entity_settlement",
    "ListEntitySettlementCostTypedDict": ".list_entity_settlement",
    "ListEntitySettlementLinks": ".list_entity_settlement",
    "ListEntitySettlementLinksTypedDict": ".list_entity_settlement",
    "ListEntitySettlementPeriods": ".list_entity_settlement",
    "ListEntitySettlementPeriodsTypedDict": ".list_entity_settlement",
    "ListEntitySettlementRate": ".list_entity_settlement",
    "ListEntitySettlementRateTypedDict": ".list_entity_settlement",
    "ListEntitySettlementRevenue": ".list_entity_settlement",
    "ListEntitySettlementRevenueTypedDict": ".list_entity_settlement",
    "ListEntitySettlementStatus": ".list_entity_settlement",
    "ListEntitySettlementTypedDict": ".list_entity_settlement",
    "ListEntityTerminal": ".list_entity_terminal",
    "ListEntityTerminalLinks": ".list_entity_terminal",
    "ListEntityTerminalLinksTypedDict": ".list_entity_terminal",
    "ListEntityTerminalStatus": ".list_entity_terminal",
    "ListEntityTerminalTypedDict": ".list_entity_terminal",
    "ListEntityWebhook": ".list_entity_webhook",
    "ListEntityWebhookLinks": ".list_entity_webhook",
    "ListEntityWebhookLinksTypedDict": ".list_entity_webhook",
    "ListEntityWebhookTypedDict": ".list_entity_webhook",
    "ListInvoicesEmbedded": ".list_invoicesop",
    "ListInvoicesEmbeddedTypedDict": ".list_invoicesop",
    "ListInvoicesRequest": ".list_invoicesop",
    "ListInvoicesRequestTypedDict": ".list_invoicesop",
    "ListInvoicesResponse": ".list_invoicesop",
    "ListInvoicesResponseBody": ".list_invoicesop",
    "ListInvoicesResponseBodyTypedDict": ".list_invoicesop",
    "ListInvoicesResponseTypedDict": ".list_invoicesop",
    "ListLinks": ".list_links",
    "ListLinksTypedDict": ".list_links",
    "ListMandateResponse": ".list_mandate_response",
    "ListMandateResponseDetails": ".list_mandate_response",
    "ListMandateResponseDetailsTypedDict": ".list_mandate_response",
    "ListMandateResponseLinks": ".list_mandate_response",
    "ListMandateResponseLinksTypedDict": ".list_mandate_response",
    "ListMandateResponseStatus": ".list_mandate_response",
    "ListMandateResponseTypedDict": ".list_mandate_response",
    "ListMandatesEmbedded": ".list_mandatesop",
    "ListMandatesEmbeddedTypedDict": ".list_mandatesop",
    "ListMandatesGlobals": ".list_mandatesop",
    "ListMandatesGlobalsTypedDict": ".list_mandatesop",
    "ListMandatesRequest": ".list_mandatesop",
    "ListMandatesRequestTypedDict": ".list_mandatesop",
    "ListMandatesResponse": ".list_mandatesop",
    "ListMandatesResponseBody": ".list_mandatesop",
    "ListMandatesResponseBodyTypedDict": ".list_mandatesop",
    "ListMandatesResponseTypedDict": ".list_mandatesop",
    "ListMethodsEmbedded": ".list_methodsop",
    "ListMethodsEmbeddedTypedDict": ".list_methodsop",
    "ListMethodsGlobals": ".list_methodsop",
    "ListMethodsGlobalsTypedDict": ".list_methodsop",
    "ListMethodsLinks": ".list_methodsop",
    "ListMethodsLinksTypedDict": ".list_methodsop",
    "ListMethodsRequest": ".list_methodsop",
    "ListMethodsRequestTypedDict": ".list_methodsop",
    "ListMethodsResponse": ".list_methodsop",
    "ListMethodsResponseTypedDict": ".list_methodsop",
    "ListPaymentLinksEmbedded": ".list_payment_linksop",
    "ListPaymentLinksEmbeddedTypedDict": ".list_payment_linksop",
    "ListPaymentLinksGlobals": ".list_payment_linksop",
    "ListPaymentLinksGlobalsTypedDict": ".list_payment_linksop",
    "ListPaymentLinksRequest": ".list_payment_linksop",
    "ListPaymentLinksRequestTypedDict": ".list_payment_linksop",
    "ListPaymentLinksResponse": ".list_payment_linksop",
    "ListPaymentLinksResponseBody": ".list_payment_linksop",
    "ListPaymentLinksResponseBodyTypedDict": ".list_payment_linksop",
    "ListPaymentLinksResponseTypedDict": ".list_payment_linksop",
    "ListPaymentResponse": ".list_payment_response",
    "ListPaymentResponseAmountCaptured": ".list_payment_response",
    "ListPaymentResponseAmountCapturedTypedDict": ".list_payment_response",
    "ListPaymentResponseAmountChargedBack": ".list_payment_response",
    "ListPaymentResponseAmountChargedBackTypedDict": ".list_payment_response",
    "ListPaymentResponseAmountRefunded": ".list_payment_response",
    "ListPaymentResponseAmountRefundedTypedDict": ".list_payment_response",
    "ListPaymentResponseAmountRemaining": ".list_payment_response",
    "ListPaymentResponseAmountRemainingTypedDict": ".list_payment_response",
    "ListPaymentResponseApplicationFee": ".list_payment_response",
    "ListPaymentResponseApplicationFeeTypedDict": ".list_payment_response",
    "ListPaymentResponseBillingAddress": ".list_payment_response",
    "ListPaymentResponseBillingAddressTypedDict": ".list_payment_response",
    "ListPaymentResponseDetails": ".list_payment_response",
    "ListPaymentResponseDetailsTypedDict": ".list_payment_response",
    "ListPaymentResponseLine": ".list_payment_response",
    "ListPaymentResponseLineTypedDict": ".list_payment_response",
    "ListPaymentResponseLinks": ".list_payment_response",
    "ListPaymentResponseLinksTypedDict": ".list_payment_response",
    "ListPaymentResponseQrCode": ".list_payment_response",
    "ListPaymentResponseQrCodeTypedDict": ".list_payment_response",
    "ListPaymentResponseReceipt": ".list_payment_response",
    "ListPaymentResponseReceiptTypedDict": ".list_payment_response",
    "ListPaymentResponseSettlementAmount": ".list_payment_response",
    "ListPaymentResponseSettlementAmountTypedDict": ".list_payment_response",
    "ListPaymentResponseStatus": ".list_payment_response",
    "ListPaymentResponseTypedDict": ".list_payment_response",
    "ListPaymentsEmbedded": ".list_paymentsop",
    "ListPaymentsEmbeddedTypedDict": ".list_paymentsop",
    "ListPaymentsGlobals": ".list_paymentsop",
    "ListPaymentsGlobalsTypedDict": ".list_paymentsop",
    "ListPaymentsRequest": ".list_paymentsop",
    "ListPaymentsRequestTypedDict": ".list_paymentsop",
    "ListPaymentsResponse": ".list_paymentsop",
    "ListPaymentsResponseBody": ".list_paymentsop",
    "ListPaymentsResponseBodyTypedDict": ".list_paymentsop",
    "ListPaymentsResponseTypedDict": ".list_paymentsop",
    "ListPermissionsEmbedded": ".list_permissionsop",
    "ListPermissionsEmbeddedTypedDict": ".list_permissionsop",
    "ListPermissionsLinks": ".list_permissionsop",
    "ListPermissionsLinksTypedDict": ".list_permissionsop",
    "ListPermissionsRequest": ".list_permissionsop",
    "ListPermissionsRequestTypedDict": ".list_permissionsop",
    "ListPermissionsResponse": ".list_permissionsop",
    "ListPermissionsResponseTypedDict": ".list_permissionsop",
    "ListProfileResponse": ".list_profile_response",
    "ListProfileResponseLinks": ".list_profile_response",
    "ListProfileResponseLinksTypedDict": ".list_profile_response",
    "ListProfileResponseReview": ".list_profile_response",
    "ListProfileResponseReviewTypedDict": ".list_profile_response",
    "ListProfileResponseStatus": ".list_profile_response",
    "ListProfileResponseTypedDict": ".list_profile_response",
    "ListProfilesEmbedded": ".list_profilesop",
    "ListProfilesEmbeddedTypedDict": ".list_profilesop",
    "ListProfilesRequest": ".list_profilesop",
    "ListProfilesRequestTypedDict": ".list_profilesop",
    "ListProfilesResponse": ".list_profilesop",
    "ListProfilesResponseBody": ".list_profilesop",
    "ListProfilesResponseBodyTypedDict": ".list_profilesop",
    "ListProfilesResponseTypedDict": ".list_profilesop",
    "ListRefundsEmbedded": ".list_refundsop",
    "ListRefundsEmbeddedTypedDict": ".list_refundsop",
    "ListRefundsGlobals": ".list_refundsop",
    "ListRefundsGlobalsTypedDict": ".list_refundsop",
    "ListRefundsRequest": ".list_refundsop",
    "ListRefundsRequestTypedDict": ".list_refundsop",
    "ListRefundsResponse": ".list_refundsop",
    "ListRefundsResponseBody": ".list_refundsop",
    "ListRefundsResponseBodyTypedDict": ".list_refundsop",
    "ListRefundsResponseTypedDict": ".list_refundsop",
    "ListRouteGetResponse": ".list_route_get_response",
    "ListRouteGetResponseDestination": ".list_route_get_response",
    "ListRouteGetResponseDestinationTypedDict": ".list_route_get_response",
    "ListRouteGetResponseLinks": ".list_route_get_response",
    "ListRouteGetResponseLinksTypedDict": ".list_route_get_response",
    "ListRouteGetResponseTypedDict": ".list_route_get_response",
    "ListSalesInvoiceResponse": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseAmountDue": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseAmountDueTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseDiscountedSubtotalAmount": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseDiscountedSubtotalAmountTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseLinks": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseLinksTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseMetadata": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseMetadataTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseSubtotalAmount": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseSubtotalAmountTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseTotalAmount": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseTotalAmountTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseTotalVatAmount": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseTotalVatAmountTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoiceResponseTypedDict": ".list_sales_invoice_response",
    "ListSalesInvoicesEmbedded": ".list_sales_invoicesop",
    "ListSalesInvoicesEmbeddedTypedDict": ".list_sales_invoicesop",
    "ListSalesInvoicesGlobals": ".list_sales_invoicesop",
    "ListSalesInvoicesGlobalsTypedDict": ".list_sales_invoicesop",
    "ListSalesInvoicesRequest": ".list_sales_invoicesop",
    "ListSalesInvoicesRequestTypedDict": ".list_sales_invoicesop",
    "ListSalesInvoicesResponse": ".list_sales_invoicesop",
    "ListSalesInvoicesResponseBody": ".list_sales_invoicesop",
    "ListSalesInvoicesResponseBodyTypedDict": ".list_sales_invoicesop",
    "ListSalesInvoicesResponseTypedDict": ".list_sales_invoicesop",
    "ListSettlementCapturesEmbedded": ".list_settlement_capturesop",
    "ListSettlementCapturesEmbeddedTypedDict": ".list_settlement_capturesop",
    "ListSettlementCapturesGlobals": ".list_settlement_capturesop",
    "ListSettlementCapturesGlobalsTypedDict": ".list_settlement_capturesop",
    "ListSettlementCapturesRequest": ".list_settlement_capturesop",
    "ListSettlementCapturesRequestTypedDict": ".list_settlement_capturesop",
    "ListSettlementCapturesResponse": ".list_settlement_capturesop",
    "ListSettlementCapturesResponseBody": ".list_settlement_capturesop",
    "ListSettlementCapturesResponseBodyTypedDict": ".list_settlement_capturesop",
    "ListSettlementCapturesResponseTypedDict": ".list_settlement_capturesop",
    "ListSettlementChargebacksEmbedded": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksEmbeddedTypedDict": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksGlobals": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksGlobalsTypedDict": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksRequest": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksRequestTypedDict": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksResponse": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksResponseBody": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksResponseBodyTypedDict": ".list_settlement_chargebacksop",
    "ListSettlementChargebacksResponseTypedDict": ".list_settlement_chargebacksop",
    "ListSettlementPaymentsEmbedded": ".list_settlement_paymentsop",
    "ListSettlementPaymentsEmbeddedTypedDict": ".list_settlement_paymentsop",
    "ListSettlementPaymentsGlobals": ".list_settlement_paymentsop",
    "ListSettlementPaymentsGlobalsTypedDict": ".list_settlement_paymentsop",
    "ListSettlementPaymentsRequest": ".list_settlement_paymentsop",
    "ListSettlementPaymentsRequestTypedDict": ".list_settlement_paymentsop",
    "ListSettlementPaymentsResponse": ".list_settlement_paymentsop",
    "ListSettlementPaymentsResponseBody": ".list_settlement_paymentsop",
    "ListSettlementPaymentsResponseBodyTypedDict": ".list_settlement_paymentsop",
    "ListSettlementPaymentsResponseTypedDict": ".list_settlement_paymentsop",
    "ListSettlementRefundsEmbedded": ".list_settlement_refundsop",
    "ListSettlementRefundsEmbeddedTypedDict": ".list_settlement_refundsop",
    "ListSettlementRefundsGlobals": ".list_settlement_refundsop",
    "ListSettlementRefundsGlobalsTypedDict": ".list_settlement_refundsop",
    "ListSettlementRefundsRequest": ".list_settlement_refundsop",
    "ListSettlementRefundsRequestTypedDict": ".list_settlement_refundsop",
    "ListSettlementRefundsResponse": ".list_settlement_refundsop",
    "ListSettlementRefundsResponseBody": ".list_settlement_refundsop",
    "ListSettlementRefundsResponseBodyTypedDict": ".list_settlement_refundsop",
    "ListSettlementRefundsResponseTypedDict": ".list_settlement_refundsop",
    "ListSettlementsEmbedded": ".list_settlementsop",
    "ListSettlementsEmbeddedTypedDict": ".list_settlementsop",
    "ListSettlementsRequest": ".list_settlementsop",
    "ListSettlementsRequestTypedDict": ".list_settlementsop",
    "ListSettlementsResponse": ".list_settlementsop",
    "ListSettlementsResponseBody": ".list_settlementsop",
    "ListSettlementsResponseBodyTypedDict": ".list_settlementsop",
    "ListSettlementsResponseTypedDict": ".list_settlementsop",
    "ListSubscriptionPaymentsEmbedded": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsEmbeddedTypedDict": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsGlobals": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsGlobalsTypedDict": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsRequest": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsRequestTypedDict": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsResponse": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsResponseBody": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsResponseBodyTypedDict": ".list_subscription_paymentsop",
    "ListSubscriptionPaymentsResponseTypedDict": ".list_subscription_paymentsop",
    "ListSubscriptionResponse": ".list_subscription_response",
    "ListSubscriptionResponseApplicationFee": ".list_subscription_response",
    "ListSubscriptionResponseApplicationFeeTypedDict": ".list_subscription_response",
    "ListSubscriptionResponseLinks": ".list_subscription_response",
    "ListSubscriptionResponseLinksTypedDict": ".list_subscription_response",
    "ListSubscriptionResponseStatus": ".list_subscription_response",
    "ListSubscriptionResponseTypedDict": ".list_subscription_response",
    "ListSubscriptionsEmbedded": ".list_subscriptionsop",
    "ListSubscriptionsEmbeddedTypedDict": ".list_subscriptionsop",
    "ListSubscriptionsGlobals": ".list_subscriptionsop",
    "ListSubscriptionsGlobalsTypedDict": ".list_subscriptionsop",
    "ListSubscriptionsRequest": ".list_subscriptionsop",
    "ListSubscriptionsRequestTypedDict": ".list_subscriptionsop",
    "ListSubscriptionsResponse": ".list_subscriptionsop",
    "ListSubscriptionsResponseBody": ".list_subscriptionsop",
    "ListSubscriptionsResponseBodyTypedDict": ".list_subscriptionsop",
    "ListSubscriptionsResponseTypedDict": ".list_subscriptionsop",
    "ListTerminalsEmbedded": ".list_terminalsop",
    "ListTerminalsEmbeddedTypedDict": ".list_terminalsop",
    "ListTerminalsGlobals": ".list_terminalsop",
    "ListTerminalsGlobalsTypedDict": ".list_terminalsop",
    "ListTerminalsRequest": ".list_terminalsop",
    "ListTerminalsRequestTypedDict": ".list_terminalsop",
    "ListTerminalsResponse": ".list_terminalsop",
    "ListTerminalsResponseBody": ".list_terminalsop",
    "ListTerminalsResponseBodyTypedDict": ".list_terminalsop",
    "ListTerminalsResponseTypedDict": ".list_terminalsop",
    "ListWebhooksEmbedded": ".list_webhooksop",
    "ListWebhooksEmbeddedTypedDict": ".list_webhooksop",
    "ListWebhooksGlobals": ".list_webhooksop",
    "ListWebhooksGlobalsTypedDict": ".list_webhooksop",
    "ListWebhooksRequest": ".list_webhooksop",
    "ListWebhooksRequestTypedDict": ".list_webhooksop",
    "ListWebhooksResponse": ".list_webhooksop",
    "ListWebhooksResponseBody": ".list_webhooksop",
    "ListWebhooksResponseBodyTypedDict": ".list_webhooksop",
    "ListWebhooksResponseTypedDict": ".list_webhooksop",
    "Locale": ".locale",
    "LocaleResponse": ".locale_response",
    "MandateDetailsCardLabelResponse": ".mandate_details_card_label_response",
    "MandateMethod": ".mandate_method",
    "MandateMethodResponse": ".mandate_method_response",
    "MandateRequest": ".mandate_request",
    "MandateRequestTypedDict": ".mandate_request",
    "MandateResponse": ".mandate_response",
    "MandateResponseDetails": ".mandate_response",
    "MandateResponseDetailsTypedDict": ".mandate_response",
    "MandateResponseLinks": ".mandate_response",
    "MandateResponseLinksTypedDict": ".mandate_response",
    "MandateResponseStatus": ".mandate_response",
    "MandateResponseTypedDict": ".mandate_response",
    "Metadata": ".metadata",
    "MetadataTypedDict": ".metadata",
    "MethodEnum": ".method_enum",
    "MethodIncludeWalletsParameter": ".method_include_wallets_parameter",
    "MethodResourceParameter": ".method_resource_parameter",
    "MethodResponse": ".method_response",
    "MethodStatus": ".method_status",
    "Mode": ".mode",
    "NoResponseError": ".no_response_error",
    "OnboardingVatRegulation": ".onboarding_vat_regulation",
    "OrganizationVatRegulation": ".organization_vat_regulation",
    "PaymentAddress": ".payment_address",
    "PaymentAddressTypedDict": ".payment_address",
    "PaymentCreateRouteRequest": ".payment_create_routeop",
    "PaymentCreateRouteRequestTypedDict": ".payment_create_routeop",
    "PaymentDetailsCardAuditionResponse": ".payment_details_card_audition_response",
    "PaymentDetailsCardFundingResponse": ".payment_details_card_funding_response",
    "PaymentDetailsCardLabelResponse": ".payment_details_card_label_response",
    "PaymentDetailsCardSecurityResponse": ".payment_details_card_security_response",
    "PaymentDetailsFailureReasonResponse": ".payment_details_failure_reason_response",
    "PaymentDetailsFeeRegionResponse": ".payment_details_fee_region_response",
    "PaymentDetailsReceiptCardReadMethodResponse": ".payment_details_receipt_card_read_method_response",
    "PaymentDetailsReceiptCardVerificationMethodResponse": ".payment_details_receipt_card_verification_method_response",
    "PaymentDetailsSellerProtectionResponse": ".payment_details_seller_protection_response",
    "PaymentDetailsWalletResponse": ".payment_details_wallet_response",
    "PaymentGetRouteRequest": ".payment_get_routeop",
    "PaymentGetRouteRequestTypedDict": ".payment_get_routeop",
    "PaymentLineItem": ".payment_line_item",
    "PaymentLineItemTypedDict": ".payment_line_item",
    "PaymentLineItemResponse": ".payment_line_item_response",
    "PaymentLineItemResponseTypedDict": ".payment_line_item_response",
    "PaymentLineType": ".payment_line_type",
    "PaymentLineTypeResponse": ".payment_line_type_response",
    "PaymentLinkMethod": ".payment_link_method",
    "PaymentLinkMethodResponse": ".payment_link_method_response",
    "PaymentLinkResponse": ".payment_link_response",
    "PaymentLinkResponseApplicationFee": ".payment_link_response",
    "PaymentLinkResponseApplicationFeeTypedDict": ".payment_link_response",
    "PaymentLinkResponseLinks": ".payment_link_response",
    "PaymentLinkResponseLinksTypedDict": ".payment_link_response",
    "PaymentLinkResponseTypedDict": ".payment_link_response",
    "PaymentLinkSequenceType": ".payment_link_sequence_type",
    "PaymentLinkSequenceTypeResponse": ".payment_link_sequence_type_response",
    "PaymentListRoutesEmbedded": ".payment_list_routesop",
    "PaymentListRoutesEmbeddedTypedDict": ".payment_list_routesop",
    "PaymentListRoutesGlobals": ".payment_list_routesop",
    "PaymentListRoutesGlobalsTypedDict": ".payment_list_routesop",
    "PaymentListRoutesLinks": ".payment_list_routesop",
    "PaymentListRoutesLinksTypedDict": ".payment_list_routesop",
    "PaymentListRoutesRequest": ".payment_list_routesop",
    "PaymentListRoutesRequestTypedDict": ".payment_list_routesop",
    "PaymentListRoutesResponse": ".payment_list_routesop",
    "PaymentListRoutesResponseTypedDict": ".payment_list_routesop",
    "PaymentMethod": ".payment_method",
    "Company": ".payment_request",
    "CompanyTypedDict": ".payment_request",
    "Method": ".payment_request",
    "MethodTypedDict": ".payment_request",
    "PaymentRequest": ".payment_request",
    "PaymentRequestApplicationFee": ".payment_request",
    "PaymentRequestApplicationFeeTypedDict": ".payment_request",
    "PaymentRequestBillingAddress": ".payment_request",
    "PaymentRequestBillingAddressTypedDict": ".payment_request",
    "PaymentRequestLine": ".payment_request",
    "PaymentRequestLineTypedDict": ".payment_request",
    "PaymentRequestTypedDict": ".payment_request",
    "PaymentResponse": ".payment_response",
    "PaymentResponseAmountCaptured": ".payment_response",
    "PaymentResponseAmountCapturedTypedDict": ".payment_response",
    "PaymentResponseAmountChargedBack": ".payment_response",
    "PaymentResponseAmountChargedBackTypedDict": ".payment_response",
    "PaymentResponseAmountRefunded": ".payment_response",
    "PaymentResponseAmountRefundedTypedDict": ".payment_response",
    "PaymentResponseAmountRemaining": ".payment_response",
    "PaymentResponseAmountRemainingTypedDict": ".payment_response",
    "PaymentResponseApplicationFee": ".payment_response",
    "PaymentResponseApplicationFeeTypedDict": ".payment_response",
    "PaymentResponseBillingAddress": ".payment_response",
    "PaymentResponseBillingAddressTypedDict": ".payment_response",
    "PaymentResponseDetails": ".payment_response",
    "PaymentResponseDetailsTypedDict": ".payment_response",
    "PaymentResponseLine": ".payment_response",
    "PaymentResponseLineTypedDict": ".payment_response",
    "PaymentResponseLinks": ".payment_response",
    "PaymentResponseLinksTypedDict": ".payment_response",
    "PaymentResponseQrCode": ".payment_response",
    "PaymentResponseQrCodeTypedDict": ".payment_response",
    "PaymentResponseReceipt": ".payment_response",
    "PaymentResponseReceiptTypedDict": ".payment_response",
    "PaymentResponseSettlementAmount": ".payment_response",
    "PaymentResponseSettlementAmountTypedDict": ".payment_response",
    "PaymentResponseStatus": ".payment_response",
    "PaymentResponseTypedDict": ".payment_response",
    "ProfileRequest": ".profile_request",
    "ProfileRequestTypedDict": ".profile_request",
    "ProfileResponse": ".profile_response",
    "ProfileResponseLinks": ".profile_response",
    "ProfileResponseLinksTypedDict": ".profile_response",
    "ProfileResponseReview": ".profile_response",
    "ProfileResponseReviewTypedDict": ".profile_response",
    "ProfileResponseStatus": ".profile_response",
    "ProfileResponseTypedDict": ".profile_response",
    "ProfileReviewStatusResponse": ".profile_review_status_response",
    "RecurringLineItem": ".recurring_line_item",
    "RecurringLineItemTypedDict": ".recurring_line_item",
    "RefundExternalReferenceType": ".refund_external_reference_type",
    "RefundExternalReferenceTypeResponse": ".refund_external_reference_type_response",
    "RefundRequest": ".refund_request",
    "RefundRequestExternalReference": ".refund_request",
    "RefundRequestExternalReferenceTypedDict": ".refund_request",
    "RefundRequestRoutingReversal": ".refund_request",
    "RefundRequestRoutingReversalTypedDict": ".refund_request",
    "RefundRequestSource": ".refund_request",
    "RefundRequestSourceTypedDict": ".refund_request",
    "RefundRequestTypedDict": ".refund_request",
    "Type": ".refund_request",
    "ReleaseAuthorizationRequest": ".release_authorizationop",
    "ReleaseAuthorizationRequestBody": ".release_authorizationop",
    "ReleaseAuthorizationRequestBodyTypedDict": ".release_authorizationop",
    "ReleaseAuthorizationRequestTypedDict": ".release_authorizationop",
    "RequestApplePayPaymentSessionRequest": ".request_apple_pay_payment_sessionop",
    "RequestApplePayPaymentSessionRequestBody": ".request_apple_pay_payment_sessionop",
    "RequestApplePayPaymentSessionRequestBodyTypedDict": ".request_apple_pay_payment_sessionop",
    "RequestApplePayPaymentSessionRequestTypedDict": ".request_apple_pay_payment_sessionop",
    "ResponseValidationError": ".responsevalidationerror",
    "RevokeMandateRequest": ".revoke_mandateop",
    "RevokeMandateRequestBody": ".revoke_mandateop",
    "RevokeMandateRequestBodyTypedDict": ".revoke_mandateop",
    "RevokeMandateRequestTypedDict": ".revoke_mandateop",
    "RouteCreateRequest": ".route_create_request",
    "RouteCreateRequestDestination": ".route_create_request",
    "RouteCreateRequestDestinationTypedDict": ".route_create_request",
    "RouteCreateRequestTypedDict": ".route_create_request",
    "RouteCreateResponse": ".route_create_response",
    "RouteCreateResponseDestination": ".route_create_response",
    "RouteCreateResponseDestinationTypedDict": ".route_create_response",
    "RouteCreateResponseLinks": ".route_create_response",
    "RouteCreateResponseLinksTypedDict": ".route_create_response",
    "RouteCreateResponseTypedDict": ".route_create_response",
    "RouteDestinationType": ".route_destination_type",
    "RouteDestinationTypeResponse": ".route_destination_type_response",
    "RouteGetResponse": ".route_get_response",
    "RouteGetResponseDestination": ".route_get_response",
    "RouteGetResponseDestinationTypedDict": ".route_get_response",
    "RouteGetResponseLinks": ".route_get_response",
    "RouteGetResponseLinksTypedDict": ".route_get_response",
    "RouteGetResponseTypedDict": ".route_get_response",
    "SalesInvoiceDiscount": ".sales_invoice_discount",
    "SalesInvoiceDiscountTypedDict": ".sales_invoice_discount",
    "SalesInvoiceDiscountResponse": ".sales_invoice_discount_response",
    "SalesInvoiceDiscountResponseTypedDict": ".sales_invoice_discount_response",
    "SalesInvoiceDiscountType": ".sales_invoice_discount_type",
    "SalesInvoiceDiscountTypeResponse": ".sales_invoice_discount_type_response",
    "SalesInvoiceEmailDetails": ".sales_invoice_email_details",
    "SalesInvoiceEmailDetailsTypedDict": ".sales_invoice_email_details",
    "SalesInvoiceLineItem": ".sales_invoice_line_item",
    "SalesInvoiceLineItemTypedDict": ".sales_invoice_line_item",
    "SalesInvoiceLineItemResponse": ".sales_invoice_line_item_response",
    "SalesInvoiceLineItemResponseTypedDict": ".sales_invoice_line_item_response",
    "SalesInvoicePaymentDetails": ".sales_invoice_payment_details",
    "SalesInvoicePaymentDetailsTypedDict": ".sales_invoice_payment_details",
    "SalesInvoicePaymentDetailsResponse": ".sales_invoice_payment_details_response",
    "SalesInvoicePaymentDetailsResponseTypedDict": ".sales_invoice_payment_details_response",
    "SalesInvoicePaymentDetailsSource": ".sales_invoice_payment_details_source",
    "SalesInvoicePaymentDetailsSourceResponse": ".sales_invoice_payment_details_source_response",
    "SalesInvoicePaymentTerm": ".sales_invoice_payment_term",
    "SalesInvoicePaymentTermResponse": ".sales_invoice_payment_term_response",
    "SalesInvoiceRecipient": ".sales_invoice_recipient",
    "SalesInvoiceRecipientTypedDict": ".sales_invoice_recipient",
    "SalesInvoiceRecipientLocale": ".sales_invoice_recipient_locale",
    "SalesInvoiceRecipientLocaleResponse": ".sales_invoice_recipient_locale_response",
    "SalesInvoiceRecipientResponse": ".sales_invoice_recipient_response",
    "SalesInvoiceRecipientResponseTypedDict": ".sales_invoice_recipient_response",
    "SalesInvoiceRecipientType": ".sales_invoice_recipient_type",
    "SalesInvoiceRecipientTypeResponse": ".sales_invoice_recipient_type_response",
    "SalesInvoiceRequest": ".sales_invoice_request",
    "SalesInvoiceRequestMetadata": ".sales_invoice_request",
    "SalesInvoiceRequestMetadataTypedDict": ".sales_invoice_request",
    "SalesInvoiceRequestTypedDict": ".sales_invoice_request",
    "SalesInvoiceResponse": ".sales_invoice_response",
    "SalesInvoiceResponseAmountDue": ".sales_invoice_response",
    "SalesInvoiceResponseAmountDueTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseDiscountedSubtotalAmount": ".sales_invoice_response",
    "SalesInvoiceResponseDiscountedSubtotalAmountTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseLinks": ".sales_invoice_response",
    "SalesInvoiceResponseLinksTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseMetadata": ".sales_invoice_response",
    "SalesInvoiceResponseMetadataTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseSubtotalAmount": ".sales_invoice_response",
    "SalesInvoiceResponseSubtotalAmountTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseTotalAmount": ".sales_invoice_response",
    "SalesInvoiceResponseTotalAmountTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseTotalVatAmount": ".sales_invoice_response",
    "SalesInvoiceResponseTotalVatAmountTypedDict": ".sales_invoice_response",
    "SalesInvoiceResponseTypedDict": ".sales_invoice_response",
    "SalesInvoiceStatus": ".sales_invoice_status",
    "SalesInvoiceStatusResponse": ".sales_invoice_status_response",
    "SalesInvoiceVatMode": ".sales_invoice_vat_mode",
    "SalesInvoiceVatModeResponse": ".sales_invoice_vat_mode_response",
    "SalesInvoiceVatScheme": ".sales_invoice_vat_scheme",
    "SalesInvoiceVatSchemeResponse": ".sales_invoice_vat_scheme_response",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SequenceType": ".sequence_type",
    "SequenceTypeResponse": ".sequence_type_response",
    "SessionLineItem": ".session_line_item",
    "SessionLineItemTypedDict": ".session_line_item",
    "SessionLineItemResponse": ".session_line_item_response",
    "SessionLineItemResponseTypedDict": ".session_line_item_response",
    "SessionRequest": ".session_request",
    "SessionRequestPayment": ".session_request",
    "SessionRequestPaymentTypedDict": ".session_request",
    "SessionRequestTypedDict": ".session_request",
    "SessionResponse": ".session_response",
    "SessionResponseLinks": ".session_response",
    "SessionResponseLinksTypedDict": ".session_response",
    "SessionResponsePayment": ".session_response",
    "SessionResponsePaymentTypedDict": ".session_response",
    "SessionResponseStatus": ".session_response",
    "SessionResponseTypedDict": ".session_response",
    "SessionSequenceType": ".session_sequence_type",
    "SessionSequenceTypeResponse": ".session_sequence_type_response",
    "Sorting": ".sorting",
    "Code": ".status_reason",
    "StatusReason": ".status_reason",
    "StatusReasonTypedDict": ".status_reason",
    "SubGroup": ".sub_group",
    "SubGroupTypedDict": ".sub_group",
    "SubTotals": ".sub_totals",
    "SubTotalsTypedDict": ".sub_totals",
    "Organization": ".submit_onboarding_dataop",
    "OrganizationTypedDict": ".submit_onboarding_dataop",
    "Profile": ".submit_onboarding_dataop",
    "ProfileTypedDict": ".submit_onboarding_dataop",
    "SubmitOnboardingDataRequest": ".submit_onboarding_dataop",
    "SubmitOnboardingDataRequestBody": ".submit_onboarding_dataop",
    "SubmitOnboardingDataRequestBodyTypedDict": ".submit_onboarding_dataop",
    "SubmitOnboardingDataRequestTypedDict": ".submit_onboarding_dataop",
    "SubscriptionMethod": ".subscription_method",
    "SubscriptionMethodResponse": ".subscription_method_response",
    "SubscriptionRequest": ".subscription_request",
    "SubscriptionRequestApplicationFee": ".subscription_request",
    "SubscriptionRequestApplicationFeeTypedDict": ".subscription_request",
    "SubscriptionRequestTypedDict": ".subscription_request",
    "SubscriptionResponse": ".subscription_response",
    "SubscriptionResponseApplicationFee": ".subscription_response",
    "SubscriptionResponseApplicationFeeTypedDict": ".subscription_response",
    "SubscriptionResponseLinks": ".subscription_response",
    "SubscriptionResponseLinksTypedDict": ".subscription_response",
    "SubscriptionResponseStatus": ".subscription_response",
    "SubscriptionResponseTypedDict": ".subscription_response",
    "TerminalBrand": ".terminal_brand",
    "TerminalModel": ".terminal_model",
    "TestWebhookRequest": ".test_webhookop",
    "TestWebhookRequestBody": ".test_webhookop",
    "TestWebhookRequestBodyTypedDict": ".test_webhookop",
    "TestWebhookRequestTypedDict": ".test_webhookop",
    "UpdateCustomerRequest": ".update_customerop",
    "UpdateCustomerRequestBody": ".update_customerop",
    "UpdateCustomerRequestBodyTypedDict": ".update_customerop",
    "UpdateCustomerRequestTypedDict": ".update_customerop",
    "UpdatePaymentLinkRequest": ".update_payment_linkop",
    "UpdatePaymentLinkRequestBody": ".update_payment_linkop",
    "UpdatePaymentLinkRequestBodyTypedDict": ".update_payment_linkop",
    "UpdatePaymentLinkRequestTypedDict": ".update_payment_linkop",
    "UpdatePaymentRequest": ".update_paymentop",
    "UpdatePaymentRequestBody": ".update_paymentop",
    "UpdatePaymentRequestBodyTypedDict": ".update_paymentop",
    "UpdatePaymentRequestTypedDict": ".update_paymentop",
    "UpdateProfileRequest": ".update_profileop",
    "UpdateProfileRequestBody": ".update_profileop",
    "UpdateProfileRequestBodyTypedDict": ".update_profileop",
    "UpdateProfileRequestTypedDict": ".update_profileop",
    "UpdateSalesInvoiceRequest": ".update_sales_invoiceop",
    "UpdateSalesInvoiceRequestBody": ".update_sales_invoiceop",
    "UpdateSalesInvoiceRequestBodyTypedDict": ".update_sales_invoiceop",
    "UpdateSalesInvoiceRequestTypedDict": ".update_sales_invoiceop",
    "UpdateSubscriptionRequest": ".update_subscriptionop",
    "UpdateSubscriptionRequestBody": ".update_subscriptionop",
    "UpdateSubscriptionRequestBodyTypedDict": ".update_subscriptionop",
    "UpdateSubscriptionRequestTypedDict": ".update_subscriptionop",
    "UpdateWebhookEventTypes": ".update_webhookop",
    "UpdateWebhookEventTypesTypedDict": ".update_webhookop",
    "UpdateWebhookRequest": ".update_webhookop",
    "UpdateWebhookRequestBody": ".update_webhookop",
    "UpdateWebhookRequestBodyTypedDict": ".update_webhookop",
    "UpdateWebhookRequestTypedDict": ".update_webhookop",
    "URL": ".url",
    "URLTypedDict": ".url",
    "URLNullable": ".url_nullable",
    "URLNullableTypedDict": ".url_nullable",
    "WebhookEventTypes": ".webhook_event_types",
    "WebhookStatus": ".webhook_status",
}

_sub_packages = ["internal"]


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name,
        package=__package__,
        dynamic_imports=_dynamic_imports,
        sub_packages=_sub_packages,
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports, sub_packages=_sub_packages)
